@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright 2009 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -46,6 +46,8 @@
 #include "common/_error.h"
 #include "common/xmlns_priv.h"
 #include "common/xmltext_priv.h"
+#include "source/oscap_source_priv.h"
+#include "source/public/oscap_source.h"
 
 /***************************************************************************/
 /* Variable definitions
@@ -113,7 +115,6 @@ OSCAP_GETTER(const struct cpe_testexpr*, cpe_platform, expr)
  * has to call parent element's 
  */
 static char *parse_text_element(xmlTextReaderPtr reader, char *name);
-static bool cpe_validate_xml(const char *filename);
 
 /* End of static declarations 
  * */
@@ -215,58 +216,19 @@ struct cpe_platform *cpe_platform_new()
  * returns the type of <structure>
  */
 
-static bool cpe_validate_xml(const char *filename)
+struct cpe_lang_model *cpe_lang_model_import_source(struct oscap_source *source)
 {
-
-	__attribute__nonnull__(filename);
-
-	xmlParserCtxtPtr ctxt;	/* the parser context */
-	xmlDocPtr doc;		/* the resulting document tree */
-	bool ret = false;
-
-	/* create a parser context */
-	ctxt = xmlNewParserCtxt();
-	if (ctxt == NULL)
-		return false;
-	/* parse the file, activating the DTD validation option */
-	doc = xmlCtxtReadFile(ctxt, filename, NULL, XML_PARSE_DTDATTR);
-	/* check if parsing suceeded */
-	if (doc == NULL) {
-		oscap_setxmlerr(xmlCtxtGetLastError(ctxt));
-		xmlFreeParserCtxt(ctxt);
-		return false;
-	}
-	/* check if validation suceeded */
-	if (ctxt->valid)
-		ret = true;
-	else			/* set xml error */
-		oscap_setxmlerr(xmlCtxtGetLastError(ctxt));
-	xmlFreeDoc(doc);
-	/* free up the parser context */
-	xmlFreeParserCtxt(ctxt);
-	return ret;
-}
-
-struct cpe_lang_model *cpe_lang_model_parse_xml(const char *file)
-{
-
-	__attribute__nonnull__(file);
-
-	xmlTextReaderPtr reader;
+	xmlTextReaderPtr reader = oscap_source_get_xmlTextReader(source);
 	struct cpe_lang_model *ret = NULL;
 
-	if (!cpe_validate_xml(file))
-		return NULL;
-
-	reader = xmlReaderForFile(file, NULL, 0);
 	if (reader != NULL) {
 		xmlTextReaderNextNode(reader);
 		ret = cpe_lang_model_parse(reader);
-	} else {
-		oscap_seterr(OSCAP_EFAMILY_GLIBC, "Unable to open file: '%s'", file);
+		if (ret != NULL) {
+			cpe_lang_model_set_origin_file(ret, oscap_source_readable_origin(source));
+		}
 	}
 	xmlFreeTextReader(reader);
-
 	return ret;
 }
 
@@ -567,7 +529,9 @@ void cpe_testexpr_export(const struct cpe_testexpr *expr, xmlTextWriterPtr write
 
 	if (expr->oper == CPE_LANG_OPER_MATCH) {
 		xmlTextWriterStartElementNS(writer, NULL, TAG_FACT_REF_STR, NULL);
-		xmlTextWriterWriteAttribute(writer, ATTR_NAME_STR, BAD_CAST cpe_name_get_as_str(expr->meta.cpe));
+		char *cpe_name_str = cpe_name_get_as_str(expr->meta.cpe);
+		xmlTextWriterWriteAttribute(writer, ATTR_NAME_STR, BAD_CAST cpe_name_str);
+		oscap_free(cpe_name_str);
 		xmlTextWriterEndElement(writer);
 	}
 	else if (expr->oper == CPE_LANG_OPER_CHECK) {
