@@ -8,7 +8,7 @@
  */
 
 /*
- * Copyright 2009 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -44,11 +44,15 @@
 #include "common/list.h"
 #include "common/_error.h"
 #include "common/xmltext_priv.h"
+#include "common/elements.h"
 
 #include "CPE/cpelang_priv.h"
 #include "CVSS/cvss_priv.h"
 #include "CVSS/public/cvss_score.h"
 
+#include "source/oscap_source_priv.h"
+#include "source/public/oscap_source.h"
+
 /***************************************************************************/
 /* Variable definitions
  * */
@@ -393,25 +397,27 @@ struct cve_model *cve_model_parse_xml(const char *file)
 
 	__attribute__nonnull__(file);
 
-	xmlTextReaderPtr reader=NULL;
 	struct cve_model *ret = NULL;
 	int rc;
 
-	reader = xmlReaderForFile(file, NULL, 0);
+	struct oscap_source *source = oscap_source_new_from_file(file);
+	xmlTextReader *reader = oscap_source_get_xmlTextReader(source);
 	if (!reader) {
-		oscap_seterr(OSCAP_EFAMILY_GLIBC, "%s '%s'", strerror(errno), file);
+		oscap_source_free(source);
 		return NULL;
 	}
 
 	rc = xmlTextReaderNextNode(reader);
 	if (rc == -1) {
 		xmlFreeTextReader(reader);
+		oscap_source_free(source);
 		return NULL;
 	}
 
 	ret = cve_model_parse(reader);
 
 	xmlFreeTextReader(reader);
+	oscap_source_free(source);
 	return ret;
 }
 
@@ -485,8 +491,12 @@ struct cve_entry *cve_entry_parse(xmlTextReaderPtr reader)
 	 * */
 	while (xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_CVE_STR) != 0) {
 
-		if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_VULNERABLE_CONFIGURATION_STR) &&
-		    xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
+		if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
+			xmlTextReaderNextNode(reader);
+			continue;
+		}
+
+		if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_VULNERABLE_CONFIGURATION_STR)) {
 
 			conf = oscap_alloc(sizeof(struct cve_configuration));
 
@@ -496,9 +506,7 @@ struct cve_entry *cve_entry_parse(xmlTextReaderPtr reader)
 
 			oscap_list_add(ret->configurations, conf);
                         continue;
-		} else
-		    if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_VULNERABLE_SOFTWARE_LIST_STR) &&
-			xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
+		} else if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_VULNERABLE_SOFTWARE_LIST_STR)) {
 			/* this will be list of products */
 			xmlTextReaderNextNode(reader);
 			while (xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_VULNERABLE_SOFTWARE_LIST_STR) != 0) {
@@ -507,39 +515,25 @@ struct cve_entry *cve_entry_parse(xmlTextReaderPtr reader)
 					product = cve_product_new();
 
                                         if (product) {
-                                                product->value = (char *)xmlTextReaderReadString(reader);
+                                                product->value = oscap_element_string_copy(reader);
 						oscap_list_add(ret->products, product);
                                         }
 				}
 				xmlTextReaderNextNode(reader);
 			}
-		} else
-		    if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_CVE_ID_STR) &&
-			xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
-			ret->cve_id = (char *)xmlTextReaderReadString(reader);
-		} else
-		    if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_PUBLISHED_DATETIME_STR) &&
-			xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
-			ret->published = (char *)xmlTextReaderReadString(reader);
-		} else
-		    if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_LAST_MODIFIED_DATETIME_STR) &&
-			xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
-			ret->modified = (char *)xmlTextReaderReadString(reader);
-		} else
-		    if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_CVSS_STR) &&
-			xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
+		} else if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_CVE_ID_STR)) {
+			ret->cve_id = oscap_element_string_copy(reader);
+		} else if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_PUBLISHED_DATETIME_STR)) {
+			ret->published = oscap_element_string_copy(reader);
+		} else if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_LAST_MODIFIED_DATETIME_STR)) {
+			ret->modified = oscap_element_string_copy(reader);
+		} else if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_CVSS_STR)) {
 		    if (ret->cvss == NULL) ret->cvss = cvss_impact_new_from_xml(reader);
-		} else
-		    if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_SECURITY_PROTECTION_STR) &&
-			xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
-			ret->sec_protection = (char *)xmlTextReaderReadString(reader);
-		} else
-		    if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_CWE_STR) &&
-			xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
+		} else if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_SECURITY_PROTECTION_STR)) {
+			ret->sec_protection = oscap_element_string_copy(reader);
+		} else if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_CWE_STR)) {
 			ret->cwe = (char *)xmlTextReaderGetAttribute(reader, ATTR_CVE_ID_STR);
-		} else
-		    if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_REFERENCES_STR) &&
-			xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
+		} else if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_REFERENCES_STR)) {
 			refer = cve_reference_new();
 
 			if (refer) {
@@ -550,31 +544,31 @@ struct cve_entry *cve_entry_parse(xmlTextReaderPtr reader)
 
 				if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_SOURCE_STR) &&
 				    xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
-				    refer->source = (char *)xmlTextReaderReadString(reader);
+				    refer->source = oscap_element_string_copy(reader);
 				} else
 				    if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_REFERENCE_STR) &&
 					xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
 					refer->href =
 					    (char *)xmlTextReaderGetAttribute(reader, ATTR_REFERENCE_HREF_STR);
-					refer->value = (char *)xmlTextReaderReadString(reader);
+					refer->value = oscap_element_string_copy(reader);
 
 				    }
 				xmlTextReaderNextNode(reader);
 			    }
 			    oscap_list_add(ret->references, refer);
 			}
-		} else
-		    if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_SUMMARY_STR) &&
-			xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
+		} else if (!xmlStrcmp(xmlTextReaderConstLocalName(reader), TAG_SUMMARY_STR)) {
 			summary = cve_summary_new();
 
                         if (summary) {
-                                summary->summary = (char *)xmlTextReaderReadString(reader);
+                                summary->summary = oscap_element_string_copy(reader);
 				oscap_list_add(ret->summaries, summary);
                         }
-		} else if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT) {
+		} else {
 			oscap_seterr(OSCAP_EFAMILY_OSCAP, "Unknown XML element in CVE entry: %s",
 				(const char*) xmlTextReaderConstLocalName(reader));
+			cve_entry_free(ret);
+			return NULL;
 		}
 
 		/* get the next node */
@@ -781,6 +775,7 @@ void cve_model_free(struct cve_model *cve_model)
 		return;
 
 	oscap_list_free(cve_model->entries, (oscap_destruct_func) cve_entry_free);
+	oscap_free(cve_model->pub_date);
 	oscap_free(cve_model->nvd_xml_version);
 	oscap_free(cve_model);
 }
