@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2013--2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -23,11 +23,14 @@
 #ifndef OPENSCAP_DS_COMMON_H
 #define OPENSCAP_DS_COMMON_H
 
+#include "common/list.h"
 #include "common/util.h"
+#include <libxml/tree.h>
 
 OSCAP_HIDDEN_START;
 
-int ds_common_mkdir_p(const char* path);
+int ds_dump_component_sources(struct oscap_htable *component_sources, const char *target_dir);
+xmlDoc *ds_doc_from_foreign_node(xmlNode *node, xmlDoc *parent);
 
 OSCAP_HIDDEN_END;
 
