@@ -89,8 +89,11 @@ static const struct oval_result_to_xccdf_spec XCCDF_OVAL_RESULTS_MAP[] = {
 oval_agent_session_t * oval_agent_new_session(struct oval_definition_model *model, const char * name) {
 	oval_agent_session_t *ag_sess;
 	struct oval_sysinfo *sysinfo;
+	struct oval_generator *generator;
 	int ret;
 
+	dI("Started new OVAL agent.", name);
+
         /* Optimalization */
         oval_definition_model_optimize_by_filter_propagation(model);
 
@@ -116,6 +119,9 @@ oval_agent_session_t * oval_agent_new_session(struct oval_definition_model *mode
 	ag_sess->sys_models[0] = ag_sess->sys_model;
 	ag_sess->sys_models[1] = NULL;
 	ag_sess->res_model = oval_results_model_new(model, ag_sess->sys_models);
+	generator = oval_results_model_get_generator(ag_sess->res_model);
+	oval_generator_set_product_version(generator, oscap_get_version());
+
 
 	ag_sess->product_name = NULL;
 
@@ -154,7 +160,15 @@ static struct oval_result_system *_oval_agent_get_first_result_system(oval_agent
 int oval_agent_eval_definition(oval_agent_session_t *ag_sess, const char *id)
 {
 	int ret;
+	const char *title = NULL;
 	struct oval_result_system *rsystem;
+	struct oval_definition *oval_def;
+
+	oval_def = oval_definition_model_get_definition(ag_sess->def_model, id);
+	if (oval_def != NULL) {
+		title = oval_definition_get_title(oval_def);
+	}
+	dI("Evaluating definition '%s': %s.", id, title);
 
 	/* probe */
 	ret = oval_probe_query_definition(ag_sess->psess, id);
@@ -246,6 +260,7 @@ int oval_agent_eval_system(oval_agent_session_t * ag_sess, agent_reporter cb, vo
 	char   *id;
 	int ret = 0;
 
+	dI("OVAL agent started to evaluate OVAL definitions on your system.");
 	oval_def_it = oval_definition_model_get_definitions(ag_sess->def_model);
 	while (oval_definition_iterator_has_more(oval_def_it)) {
 		oval_def = oval_definition_iterator_next(oval_def_it);
@@ -275,6 +290,7 @@ int oval_agent_eval_system(oval_agent_session_t * ag_sess, agent_reporter cb, vo
 
 cleanup:
 	oval_definition_iterator_free(oval_def_it);
+	dI("OVAL agent finished evaluation.");
 	return ret;
 }
 
@@ -291,14 +307,14 @@ const char * oval_agent_get_filename(oval_agent_session_t * ag_sess) {
 }
 
 void oval_agent_destroy_session(oval_agent_session_t * ag_sess) {
-	if (ag_sess->product_name)
+	if (ag_sess != NULL) {
 		oscap_free(ag_sess->product_name);
-	oval_probe_session_destroy(ag_sess->psess);
-	oval_syschar_model_free(ag_sess->sys_model);
-	oval_results_model_free(ag_sess->res_model);
-        oscap_free(ag_sess->filename);
-	oscap_free(ag_sess);
-	ag_sess=NULL;
+		oval_probe_session_destroy(ag_sess->psess);
+		oval_syschar_model_free(ag_sess->sys_model);
+		oval_results_model_free(ag_sess->res_model);
+	        oscap_free(ag_sess->filename);
+		oscap_free(ag_sess);
+	}
 }
 
 
@@ -333,8 +349,12 @@ static struct oscap_htable *_binding_iterator_to_dict(struct xccdf_value_binding
 		struct xccdf_value_binding *binding = xccdf_value_binding_iterator_next(it);
 		const char *var_name = xccdf_value_binding_get_name(binding);
 		const char *var_val = xccdf_value_binding_get_setvalue(binding);
-		if (var_val == NULL)
+		if (var_val == NULL) {
 			var_val = xccdf_value_binding_get_value(binding);
+			if (var_val == NULL) {
+				var_val = "";
+			}
+		}
 		struct oscap_stringlist *list = (struct oscap_stringlist *) oscap_htable_get(dict, var_name);
 		if (list == NULL) {
 			list = oscap_stringlist_new();
@@ -482,7 +502,12 @@ int oval_agent_resolve_variables(struct oval_agent_session * session, struct xcc
         struct xccdf_value_binding *binding = xccdf_value_binding_iterator_next(it);
         char *name = xccdf_value_binding_get_name(binding);
         char * value = xccdf_value_binding_get_setvalue(binding);
-        if (value == NULL) value = xccdf_value_binding_get_value(binding);
+        if (value == NULL) {
+		value = xccdf_value_binding_get_value(binding);
+		if (value == NULL) {
+			value = "";
+		}
+	}
         struct oval_variable *variable = oval_definition_model_get_variable(def_model, name);
         if (variable != NULL) {
                 oval_datatype_t o_type = oval_variable_get_datatype(variable);
@@ -490,13 +515,13 @@ int oval_agent_resolve_variables(struct oval_agent_session * session, struct xcc
 			/* Add variable to variable model */
 			oval_variable_model_add(session->cur_var_model, name, "Unknown", o_type, value);
 			oval_variable_bind_ext_var(variable, session->cur_var_model, name);
-			oscap_dlprintf(DBG_I, "Adding external variable %s.\n", name);
+			dI("Adding external variable %s.", name);
 		} else {
 			/* Skip this variable (we assume it has same values otherwise conflict was detected) */
-			oscap_dlprintf(DBG_W, "Skipping external variable %s.\n", name);
+			dW("Skipping external variable %s.", name);
 		}
         } else {
-                oscap_dlprintf(DBG_W, "Variable %s does not exist, skipping.\n", name);
+                dW("Variable %s does not exist, skipping.", name);
         }
     }
 
