@@ -46,6 +46,7 @@
 #include "oval_agent_api_impl.h"
 #include "oval_parser_impl.h"
 #include "oval_probe_session.h"
+#include "oval_probe_impl.h"
 #include "common/util.h"
 #include "common/debug_priv.h"
 #include "common/_error.h"
@@ -333,7 +334,7 @@ void oval_component_set_record_field(struct oval_component *component, char *fie
 	__attribute__nonnull__(component);
 
 	if (oval_component_get_type(component) != OVAL_COMPONENT_OBJECTREF) {
-		dW("Wrong component type: %d.\n", oval_component_get_type(component));
+		dW("Wrong component type: %d.", oval_component_get_type(component));
 		return;
 	}
 
@@ -1055,9 +1056,7 @@ static int _oval_component_parse_GLOB_TO_REGEX_tag(xmlTextReaderPtr reader,
 	__attribute__nonnull__(component);
 
 	oval_component_GLOB_t *glob_to_regex = (oval_component_GLOB_t *) component;
-	char *glob_noescape = (char *)xmlTextReaderGetAttribute(reader, BAD_CAST "glob_noescape");
-	glob_to_regex->glob_noescape = (glob_noescape != NULL && strcmp(glob_noescape, "true") == 0);
-	oscap_free(glob_noescape);
+	glob_to_regex->glob_noescape = oval_parser_boolean_attribute(reader, "glob_noescape", 0);
 
 	return _oval_component_parse_FUNCTION_tag(reader, context, component);
 }
@@ -1172,7 +1171,7 @@ int oval_component_parse_tag(xmlTextReaderPtr reader,
 		component = oval_component_new(model, OVAL_FUNCTION_REGEX_CAPTURE);
 		return_code = _oval_component_parse_REGEX_CAPTURE_tag(reader, context, component);
 	} else {
-		oscap_dlprintf(DBG_I, "Tag <%s> not handled, line: %d.\n", tagname,
+		dI("Tag <%s> not handled, line: %d.", tagname,
                               xmlTextReaderGetParserLineNumber(reader));
 		return_code = oval_parser_skip_tag(reader, context);
 	}
@@ -1180,7 +1179,7 @@ int oval_component_parse_tag(xmlTextReaderPtr reader,
 		(*consumer) (component, user);
 
 	if (return_code != 0 ) {
-		dW("Parsing of <%s> terminated by an error at line %d.\n", tagname, xmlTextReaderGetParserLineNumber(reader));
+		dW("Parsing of <%s> terminated by an error at line %d.", tagname, xmlTextReaderGetParserLineNumber(reader));
 	}
 	oscap_free(tagname);
 	return return_code;
@@ -1339,13 +1338,13 @@ static oval_syschar_collection_flag_t _oval_component_evaluate_OBJECTREF(oval_ar
 	if (!object)
 		return flag;
 
+	const char *obj_id = oval_object_get_id(object);
+	dI("Variable component references to object '%s'.", obj_id);
+
 	if (argu->mode == OVAL_MODE_QUERY) {
 		if (oval_probe_query_object(argu->u.sess, object, 0, &syschar) != 0)
 			return flag;
 	} else {
-		char *obj_id;
-
-		obj_id = oval_object_get_id(object);
 		syschar = oval_syschar_model_get_syschar(argu->u.sysmod, obj_id);
 	}
 
@@ -1359,6 +1358,9 @@ static oval_syschar_collection_flag_t _oval_component_evaluate_OBJECTREF(oval_ar
 		while (oval_sysitem_iterator_has_more(sysitems)) {
 			struct oval_sysitem *sysitem = oval_sysitem_iterator_next(sysitems);
 			struct oval_sysent_iterator *sysent_itr = oval_sysitem_get_sysents(sysitem);
+			const char *oval_sysitem_id = oval_sysitem_get_id(sysitem);
+			const char *oval_sysitem_subtype = oval_subtype_to_str(oval_sysitem_get_subtype(sysitem));
+			bool entity_matched = false;
 			while (oval_sysent_iterator_has_more(sysent_itr)) {
 				oval_datatype_t dt;
 				struct oval_sysent *sysent = oval_sysent_iterator_next(sysent_itr);
@@ -1367,14 +1369,28 @@ static oval_syschar_collection_flag_t _oval_component_evaluate_OBJECTREF(oval_ar
 				if (strcmp(ifield_name, sysent_name))
 					continue;
 
+				entity_matched = true;
 				dt = oval_sysent_get_datatype(sysent);
-				if ((dt == OVAL_DATATYPE_RECORD && rfield_name == NULL)
-				    || (dt != OVAL_DATATYPE_RECORD && rfield_name != NULL))
-					/* todo: throw error */
-					continue;
+				if (dt == OVAL_DATATYPE_RECORD && rfield_name == NULL) {
+					oscap_seterr(OSCAP_EFAMILY_OVAL,
+							"Unexpected record data type in %s_item (id: %s) specified by object '%s'.",
+							oval_sysitem_subtype, oval_sysitem_id, obj_id);
+					oval_sysent_iterator_free(sysent_itr);
+					oval_sysitem_iterator_free(sysitems);
+					return SYSCHAR_FLAG_ERROR;
+				}
+				if (dt != OVAL_DATATYPE_RECORD && rfield_name != NULL) {
+					oscap_seterr(OSCAP_EFAMILY_OVAL,
+							"Expected record data type, but found %s data type in %s entity in %s_item (id: %s) specified by object '%s'.",
+							oval_datatype_get_text(dt), ifield_name, oval_sysitem_subtype, oval_sysitem_id, obj_id);
+					oval_sysent_iterator_free(sysent_itr);
+					oval_sysitem_iterator_free(sysitems);
+					return SYSCHAR_FLAG_ERROR;
+				}
 
 				if (dt == OVAL_DATATYPE_RECORD) {
 					struct oval_record_field_iterator *rf_itr;
+					bool field_matched = false;
 
 					rf_itr = oval_sysent_get_record_fields(sysent);
 					while (oval_record_field_iterator_has_more(rf_itr)) {
@@ -1387,13 +1403,23 @@ static oval_syschar_collection_flag_t _oval_component_evaluate_OBJECTREF(oval_ar
 						if (strcmp(rfield_name, txtval))
 							continue;
 
+						field_matched = true;
 						dt = oval_record_field_get_datatype(rf);
 						txtval = oval_record_field_get_value(rf);
 						val = oval_value_new(dt, txtval);
 						oval_collection_add(value_collection, val);
 					}
+					/* throw error if none matched */
+					if (!field_matched) {
+						oscap_seterr(OSCAP_EFAMILY_OVAL,
+								"Record field '%s' has not been found in %s_item (id: %s) specified by object '%s'.",
+								rfield_name, oval_sysitem_subtype, oval_sysitem_id, obj_id);
+						oval_record_field_iterator_free(rf_itr);
+						oval_sysent_iterator_free(sysent_itr);
+						oval_sysitem_iterator_free(sysitems);
+						return SYSCHAR_FLAG_ERROR;
+					}
 					oval_record_field_iterator_free(rf_itr);
-					/* todo: throw error if none matched */
 				} else {
 					char *txtval;
 					struct oval_value *val;
@@ -1403,8 +1429,16 @@ static oval_syschar_collection_flag_t _oval_component_evaluate_OBJECTREF(oval_ar
 					oval_collection_add(value_collection, val);
 				}
 			}
+			/* throw error if none matched */
+			if (!entity_matched) {
+				oscap_seterr(OSCAP_EFAMILY_OVAL,
+						"Entity '%s' has not been found in %s_item (id: %s) specified by object '%s'.",
+						ifield_name, oval_sysitem_subtype, oval_sysitem_id, obj_id);
+				oval_sysent_iterator_free(sysent_itr);
+				oval_sysitem_iterator_free(sysitems);
+				return SYSCHAR_FLAG_ERROR;
+			}
 			oval_sysent_iterator_free(sysent_itr);
-			/* todo: throw error if none matched */
 		}
 		oval_sysitem_iterator_free(sysitems);
 	}
@@ -1864,23 +1898,23 @@ static long unsigned int _parse_datetime(char *datetime, const char *fmt[], size
         size_t    i;
         char     *r;
 
-        dI("Parsing datetime string \"%s\"\n", datetime);
+        dI("Parsing datetime string \"%s\"", datetime);
 
         for (i = 0; i < fmtcnt; ++i) {
-                dI("%s\n", fmt[i]);
+                dI("%s", fmt[i]);
                 memset(&t, 0, sizeof t);
                 r = strptime(datetime, fmt[i], &t);
 
                 if (r != NULL) {
                         if (*r == '\0') {
-                                dI("Success!\n");
+                                dI("Success!");
                                 return _comp_sec(t.tm_year, t.tm_mon, t.tm_mday,
                                                  t.tm_hour, t.tm_min, t.tm_sec);
                         }
                 }
         }
 
-        dE("Unable to interpret \"%s\" as a datetime string\n");
+        dE("Unable to interpret \"%s\" as a datetime string");
 
         return (0);
 }
@@ -1904,6 +1938,49 @@ static long unsigned int _parse_fmt_sse(char *dt)
 	return (long unsigned int) t;
 }
 
+static bool _match(const char *pattern, const char *string)
+{
+	bool match = false;
+#if defined USE_REGEX_PCRE
+	pcre *re;
+	const char *error;
+	int erroffset = -1, ovector[60], ovector_len = sizeof (ovector) / sizeof (ovector[0]);
+	re = pcre_compile(pattern, PCRE_UTF8, &error, &erroffset, NULL);
+	match = (pcre_exec(re, NULL, string, strlen(string), 0, 0, ovector, ovector_len) >= 0);
+	pcre_free(re);
+#elif defined USE_REGEX_POSIX
+	regex_t re;
+	regcomp(&re, pattern, REG_EXTENDED);
+	match = (regexec(&re, string, 0, NULL, 0) == 0);
+	regfree(&re);
+#endif
+	return match;
+}
+
+static long unsigned int _parse_fmt_cim(char *dt)
+{
+	const char *pattern1 = "^[0-9]{14}\\.[0-9]{6}[+-][0-9]{3}$"; // yyyymmddHHMMSS.mmmmmmsUUU
+	const char *fmt_str1 = "%4u%2u%2u%2u%2u%2u.%*6u%*[+-]%*3u";
+	const char *pattern2 = "^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}:[0-9]{3}$"; // yyyy-mm-dd HH:MM:SS:mmm
+	const char *fmt_str2 = "%4d-%2d-%2d %2d:%2d:%2d:%*3d";
+	const char *pattern3 = "^[0-9]{2}-[0-9]{2}-[0-9]{4} [0-9]{2}:[0-9]{2}:[0-9]{2}:[0-9]{3}$"; // mm-dd-yyyy hh:mm:ss:mmm
+	const char *fmt_str3 = "%2d-%2d-%4d %2d:%2d:%2d:%*3d";
+	int year, month, day, hour, minute, second, r = 0;
+	const int number_of_items = 6;
+	if (_match(pattern1, dt)) {
+		r = sscanf(dt, fmt_str1, &year, &month, &day, &hour, &minute, &second);
+	} else if (_match(pattern2, dt)) {
+		r = sscanf(dt, fmt_str2, &year, &month, &day, &hour, &minute, &second);
+	} else if (_match(pattern3, dt)) {
+		r = sscanf(dt, fmt_str3, &month, &day, &year, &hour, &minute, &second);
+	}
+	if (r != number_of_items) {
+		oscap_seterr(OSCAP_EFAMILY_OSCAP, "Unable to interpret \"%s\" as a cim_datetime string\n", dt);
+		return 0;
+	}
+	return _comp_sec(year, month, day, hour, minute, second);
+}
+
 static long unsigned int _parse_fmt(struct oval_value *val, oval_datetime_format_t fmt)
 {
 	long unsigned int v = 0;
@@ -1927,6 +2004,9 @@ static long unsigned int _parse_fmt(struct oval_value *val, oval_datetime_format
 	case OVAL_DATETIME_SECONDS_SINCE_EPOCH:
 		v = _parse_fmt_sse(sv);
 		break;
+	case OVAL_DATETIME_CIM_DATETIME:
+		v = _parse_fmt_cim(sv);
+		break;
 	default:
 		break;
 	}
@@ -2102,7 +2182,7 @@ static oval_syschar_collection_flag_t _oval_component_evaluate_REGEX_CAPTURE(ova
 	pattern = oval_component_get_regex_pattern(component);
 	re = pcre_compile(pattern, PCRE_UTF8, &error, &erroffset, NULL);
 	if (re == NULL) {
-		oscap_dlprintf(DBG_E, "pcre_compile() failed: \"%s\".\n", error);
+		dE("pcre_compile() failed: \"%s\".", error);
 		return SYSCHAR_FLAG_ERROR;
 	}
 #elif defined USE_REGEX_POSIX
@@ -2110,7 +2190,7 @@ static oval_syschar_collection_flag_t _oval_component_evaluate_REGEX_CAPTURE(ova
 
 	pattern = oval_component_get_regex_pattern(component);
 	if ((rc = regcomp(&re, pattern, REG_EXTENDED | REG_NEWLINE)) != 0) {
-		oscap_dlprintf(DBG_E, "regcomp() failed: %d.\n", rc);
+		dE("regcomp() failed: %d.", rc);
 		return SYSCHAR_FLAG_ERROR;
 	}
 #endif
@@ -2132,7 +2212,7 @@ static oval_syschar_collection_flag_t _oval_component_evaluate_REGEX_CAPTURE(ova
 
 			rc = pcre_exec(re, NULL, text, strlen(text), 0, 0, ovector, ovector_len);
 			if (rc < -1) {
-				oscap_dlprintf(DBG_E, "pcre_exec() failed: %d.\n", rc);
+				dE("pcre_exec() failed: %d.", rc);
 				flag = SYSCHAR_FLAG_ERROR;
 				break;
 			}
