@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright 2009-2010 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -37,7 +37,7 @@
 #include <string.h>
 
 #include "oval_definitions_impl.h"
-#include "oval_collection_impl.h"
+#include "adt/oval_collection_impl.h"
 #include "oval_agent_api_impl.h"
 #include "common/util.h"
 #include "common/debug_priv.h"
@@ -428,7 +428,7 @@ int oval_criteria_parse_tag(xmlTextReaderPtr reader, struct oval_parser_context
 		(*consumer) (node, user);
 	} else {
 		return_code = 1;
-		oscap_dlprintf(DBG_W, "Invalid node type: OVAL_NODETYPE_UNKNOWN.\n");
+		dW("Invalid node type: OVAL_NODETYPE_UNKNOWN.");
 		oval_parser_skip_tag(reader, context);
 	}
 	oscap_free(tagname);
