@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -45,6 +45,8 @@
 #include "common/debug_priv.h"
 #include "common/_error.h"
 #include "common/elements.h"
+#include "oscap_source.h"
+#include "source/oscap_source_priv.h"
 
 typedef struct oval_definition_model {
 	struct oval_generator *generator;
@@ -121,32 +123,24 @@ struct oval_definition_model *oval_definition_model_clone(struct oval_definition
 
 void oval_definition_model_free(struct oval_definition_model *model)
 {
-	__attribute__nonnull__(model);
-
-	oval_string_map_free(model->definition_map, (oscap_destruct_func) oval_definition_free);
-	oval_string_map_free(model->object_map, (oscap_destruct_func) oval_object_free);
-	oval_string_map_free(model->state_map, (oscap_destruct_func) oval_state_free);
-	oval_string_map_free(model->test_map, (oscap_destruct_func) oval_test_free);
-	oval_string_map_free(model->variable_map, (oscap_destruct_func) oval_variable_free);
-	if (model->vardef_map != NULL)
-		oval_string_map_free(model->vardef_map, (oscap_destruct_func) oval_string_map_free0);
-	if (model->bound_variable_models)
-		oval_collection_free_items(model->bound_variable_models,
+	if (model != NULL) {
+		oval_string_map_free(model->definition_map, (oscap_destruct_func) oval_definition_free);
+		oval_string_map_free(model->object_map, (oscap_destruct_func) oval_object_free);
+		oval_string_map_free(model->state_map, (oscap_destruct_func) oval_state_free);
+		oval_string_map_free(model->test_map, (oscap_destruct_func) oval_test_free);
+		oval_string_map_free(model->variable_map, (oscap_destruct_func) oval_variable_free);
+		if (model->vardef_map != NULL)
+			oval_string_map_free(model->vardef_map, (oscap_destruct_func) oval_string_map_free0);
+		if (model->bound_variable_models)
+			oval_collection_free_items(model->bound_variable_models,
 					   (oscap_destruct_func) oval_variable_model_free);
 
-        if (model->schema != NULL)
-            oscap_free(model->schema);
+	        if (model->schema != NULL)
+			oscap_free(model->schema);
 
-	model->definition_map = NULL;
-	model->object_map = NULL;
-	model->state_map = NULL;
-	model->test_map = NULL;
-	model->variable_map = NULL;
-        model->schema = NULL;
-
-	oval_generator_free(model->generator);
-
-	oscap_free(model);
+		oval_generator_free(model->generator);
+		oscap_free(model);
+	}
 }
 
 struct oval_generator *oval_definition_model_get_generator(struct oval_definition_model *model)
@@ -167,6 +161,33 @@ const char * oval_definition_model_get_schema(struct oval_definition_model * mod
         return model->schema;
 }
 
+oval_version_t oval_definition_model_get_schema_version(struct oval_definition_model *model)
+{
+	if (model == NULL || model->generator == NULL) {
+		return OVAL_VERSION_INVALID;
+	}
+	const char *ver_str = oval_generator_get_core_schema_version(model->generator);
+	return oval_version_from_cstr(ver_str);
+}
+
+oval_schema_version_t oval_definition_model_get_core_schema_version(struct oval_definition_model *model)
+{
+	if (model == NULL || model->generator == NULL) {
+		return OVAL_SCHEMA_VERSION_INVALID;
+	}
+	const char *version = oval_generator_get_core_schema_version(model->generator);
+	return oval_schema_version_from_cstr(version);
+}
+
+oval_schema_version_t oval_definition_model_get_platform_schema_version(struct oval_definition_model *model, const char *platform)
+{
+	if (model == NULL || model->generator == NULL) {
+		return OVAL_SCHEMA_VERSION_INVALID;
+	}
+	const char *version = oval_generator_get_platform_schema_version(model->generator, platform);
+	return oval_schema_version_from_cstr(version);
+}
+
 void oval_definition_model_add_definition(struct oval_definition_model *model, struct oval_definition *definition)
 {
 	__attribute__nonnull__(model);
@@ -208,16 +229,41 @@ void oval_definition_model_add_variable(struct oval_definition_model *model, str
 	oval_string_map_put(model->variable_map, key, (void *)variable);
 }
 
-struct oval_definition_model * oval_definition_model_import(const char *file)
+static inline int _oval_definition_model_merge_source(struct oval_definition_model *model, struct oscap_source *source)
+{
+	/* setup context */
+	struct oval_parser_context context;
+	context.reader = oscap_source_get_xmlTextReader(source);
+	if (context.reader == NULL) {
+		return -1;
+	}
+	context.definition_model = model;
+	context.user_data = NULL;
+	/* jump into oval_definitions */
+	while (xmlTextReaderRead(context.reader) == 1
+		&& xmlTextReaderNodeType(context.reader) != XML_READER_TYPE_ELEMENT) ;
+	/* start parsing */
+	int ret = oval_definition_model_parse(context.reader, &context);
+	xmlFreeTextReader(context.reader);
+	return ret;
+}
+
+struct oval_definition_model *oval_definition_model_import_source(struct oscap_source *source)
 {
         struct oval_definition_model *model = oval_definition_model_new();
-        int ret = oval_definition_model_merge(model,file);
+	int ret = _oval_definition_model_merge_source(model, source);
         if (ret == -1 ) {
-		oscap_dlprintf(DBG_E, "Failed to merge the definition model from: %s.\n", file);
                 oval_definition_model_free(model);
                 model = NULL;
         }
+	return model;
+}
 
+struct oval_definition_model * oval_definition_model_import(const char *file)
+{
+	struct oscap_source *source = oscap_source_new_from_file(file);
+	struct oval_definition_model *model = oval_definition_model_import_source(source);
+	oscap_source_free(source);
         return model;
 }
 
@@ -227,23 +273,10 @@ int oval_definition_model_merge(struct oval_definition_model *model, const char
 
 	int ret;
 
-	xmlTextReader *reader = xmlNewTextReaderFilename(file);
-	if (reader == NULL) {
-		oscap_seterr(OSCAP_EFAMILY_GLIBC, "%s '%s'", strerror(errno), file);
-		return -1;
-	}
+	struct oscap_source *source = oscap_source_new_from_file(file);
+	ret = _oval_definition_model_merge_source(model, source);
 
-	/* setup context */
-	struct oval_parser_context context;
-	context.reader = reader;
-	context.definition_model = model;
-	context.user_data = NULL;
-	xmlTextReaderSetErrorHandler(reader, &libxml_error_handler, &context);
-	/* jump into oval_definitions */
-	while (xmlTextReaderRead(reader) == 1 && xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) ;
-	/* start parsing */
-	ret = oval_definition_model_parse(reader, &context);
-	xmlFreeTextReader(reader);
+	oscap_source_free(source);
 
 	return ret;
 }
@@ -458,17 +491,15 @@ xmlNode *oval_definition_model_to_dom(struct oval_definition_model *definition_m
 		root_node = xmlNewNode(NULL, BAD_CAST OVAL_ROOT_ELM_DEFINITIONS);
 		xmlDocSetRootElement(doc, root_node);
 	}
-	xmlNewProp(root_node, BAD_CAST "xsi:schemaLocation", BAD_CAST definition_model->schema);
+	xmlNewNsProp(root_node, lookup_xsi_ns(doc), BAD_CAST "schemaLocation", BAD_CAST definition_model->schema);
 
 	xmlNs *ns_common = xmlNewNs(root_node, OVAL_COMMON_NAMESPACE, BAD_CAST "oval");
-	xmlNs *ns_xsi = xmlNewNs(root_node, OVAL_XMLNS_XSI, BAD_CAST "xsi");
 	xmlNs *ns_unix = xmlNewNs(root_node, OVAL_DEFINITIONS_UNIX_NS, BAD_CAST "unix-def");
 	xmlNs *ns_ind = xmlNewNs(root_node, OVAL_DEFINITIONS_IND_NS, BAD_CAST "ind-def");
 	xmlNs *ns_lin = xmlNewNs(root_node, OVAL_DEFINITIONS_LIN_NS, BAD_CAST "lin-def");
 	xmlNs *ns_defntns = xmlNewNs(root_node, OVAL_DEFINITIONS_NAMESPACE, NULL);
 
 	xmlSetNs(root_node, ns_common);
-	xmlSetNs(root_node, ns_xsi);
 	xmlSetNs(root_node, ns_unix);
 	xmlSetNs(root_node, ns_ind);
 	xmlSetNs(root_node, ns_lin);
@@ -555,7 +586,7 @@ int oval_definition_model_export(struct oval_definition_model *model, const char
 	}
 
 	oval_definition_model_to_dom(model, doc, NULL);
-	return oscap_xml_save_filename(file, doc);
+	return oscap_xml_save_filename_free(file, doc);
 }
 
 static void _fp_set_recurse(struct oval_definition_model *model, struct oval_setobject *set, char *set_id)
