@@ -147,6 +147,7 @@ static const struct oscap_string_map OVAL_DATETIME_FORMAT_MAP[] = {
 	{OVAL_DATETIME_DAY_MONTH_YEAR, "day_month_year"},
 	{OVAL_DATETIME_WIN_FILETIME, "win_filetime"},
 	{OVAL_DATETIME_SECONDS_SINCE_EPOCH, "seconds_since_epoch"},
+	{OVAL_DATETIME_CIM_DATETIME, "cim_datetime"},
 	{OVAL_ENUMERATION_INVALID, NULL}
 };
 
@@ -245,6 +246,7 @@ const char *oval_check_get_text(oval_check_t check)
 static const struct oscap_string_map OVAL_DATATYPE_MAP[] = {
 	{OVAL_DATATYPE_BINARY, "binary"},
 	{OVAL_DATATYPE_BOOLEAN, "boolean"},
+	{OVAL_DATATYPE_DEBIAN_EVR_STRING, "debian_evr_string"},
 	{OVAL_DATATYPE_EVR_STRING, "evr_string"},
 	{OVAL_DATATYPE_FILESET_REVISION, "fileset_revision"},
 	{OVAL_DATATYPE_FLOAT, "float"},
@@ -376,7 +378,7 @@ oval_family_t oval_family_parse(xmlTextReaderPtr reader)
 	}
 	char *family_text = strrchr(namespace, '#');
 	if (family_text == NULL) {
-		dW("No OVAL family for namespace: %s\n", namespace);
+		dW("No OVAL family for namespace: %s", namespace);
 		oscap_free(namespace);
 		return OVAL_FAMILY_UNKNOWN;
 	}
@@ -384,7 +386,7 @@ oval_family_t oval_family_parse(xmlTextReaderPtr reader)
 	int ret = oscap_string_to_enum(OVAL_FAMILY_MAP, ++family_text);
 
 	if (ret == OVAL_ENUMERATION_INVALID) {
-		dW("Unknown OVAL family: %s\n", family_text);
+		dW("Unknown OVAL family: %s", family_text);
 		ret = OVAL_FAMILY_UNKNOWN;
 	}
 
@@ -397,6 +399,18 @@ const char *oval_family_get_text(oval_family_t family)
 	return oval_enumeration_get_text(OVAL_FAMILY_MAP, family);
 }
 
+xmlNs *oval_family_to_namespace(oval_family_t family, const char *schema_ns, xmlDoc *doc, xmlNode *parent)
+{
+	const char *family_text = oval_family_get_text(family);
+	if (family_text == NULL) {
+		return NULL;
+	}
+	/* We need to allocate memory also for '#' and '\0'. */
+	char family_uri[strlen(schema_ns) + 1 + strlen(family_text) + 1];
+	sprintf(family_uri,"%s#%s", schema_ns, family_text);
+	return xmlSearchNsByHref(doc, parent, BAD_CAST family_uri);
+}
+
 static const struct oscap_string_map OVAL_SUBTYPE_AIX_MAP[] = {
 	{OVAL_AIX_FILESET, "fileset"},
 	{OVAL_AIX_FIX, "fix"},
@@ -533,6 +547,7 @@ static const struct oscap_string_map OVAL_SUBTYPE_UNIX_MAP[] = {
         {OVAL_UNIX_FILEEXTENDEDATTRIBUTE, "fileextendedattribute"},
         {OVAL_UNIX_GCONF, "gconf"},
         {OVAL_UNIX_ROUTINGTABLE, "routingtable"},
+	{OVAL_UNIX_SYMLINK, "symlink"},
 	{OVAL_SUBTYPE_UNKNOWN, NULL}
 };
 
@@ -636,7 +651,7 @@ oval_subtype_t oval_subtype_parse(xmlTextReaderPtr reader)
 
 	int subtype_s = oscap_string_to_enum(map, tagname);
 	if (subtype < 0) {
-		dW("Unknown OVAL family subtype: %s\n", tagname);
+		dW("Unknown OVAL family subtype: %s", tagname);
 		subtype = OVAL_ENUMERATION_INVALID;
 	}
 	else {
@@ -706,7 +721,7 @@ const char *oval_subtype_get_text(oval_subtype_t subtype)
 	if (map) {
 		return oval_enumeration_get_text(map, subtype);
 	} else {
-		oscap_seterr(OSCAP_EFAMILY_OSCAP, "Warning: Zero family index");
+		oscap_seterr(OSCAP_EFAMILY_OVAL, "Invalid OVAL family.");
 		return _invalid;
 	}
 }
