@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright 2009-2010 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -36,7 +36,7 @@
 #include <string.h>
 
 #include "oval_definitions_impl.h"
-#include "oval_collection_impl.h"
+#include "adt/oval_collection_impl.h"
 #include "oval_agent_api_impl.h"
 #include "common/util.h"
 #include "common/debug_priv.h"
@@ -193,7 +193,7 @@ struct oval_object_content
 		}
 		break;
 	default:
-		dE("Unsupported object content type: %d.\n", type);
+		dE("Unsupported object content type: %d.", type);
 		return NULL;
 	}
 	content->model = model;
@@ -389,7 +389,7 @@ int oval_object_content_parse_tag(xmlTextReaderPtr reader,
 	(*consumer) (content, user);
 
 	if (return_code != 0)
-		dW("Parsing of <%s> terminated by an error at line %d.\n",tagname, xmlTextReaderGetParserLineNumber(reader));
+		dW("Parsing of <%s> terminated by an error at line %d.",tagname, xmlTextReaderGetParserLineNumber(reader));
 
 	oscap_free(namespace);
 	return return_code;
@@ -403,7 +403,8 @@ xmlNode *oval_object_content_to_dom(struct oval_object_content *content, xmlDoc
 			struct oval_entity *entity = oval_object_content_get_entity(content);
 			content_node = oval_entity_to_dom(entity, doc, parent);
 			oval_check_t check = oval_object_content_get_varCheck(content);
-			if (check != OVAL_CHECK_ALL)
+
+			if (check != OVAL_CHECK_ALL || xmlHasProp(content_node, BAD_CAST "var_ref"))
 				xmlNewProp(content_node, BAD_CAST "var_check", BAD_CAST oval_check_get_text(check));
 		}
 		break;
