@@ -79,6 +79,19 @@ static void ncache_libinit(void)
 
 static void oval_probe_session_libinit(void)
 {
+	/* HACK: Make sure S-exps are initialized before we initialize anything else
+	 * that uses them. This is needed only if the S-exp library is compiled without
+	 * atomic builtins. In that case it uses a fallback locking mechanism that uses
+	 * a mutex array which needs to be initialized before S-exp are used and freed
+	 * at exit(3). The later is done by registering an atexit(3) function.
+	 * The ncache_libinit function also registers an atexit(3) function and we need
+	 * to make sure that the S-exps are not deinitialized before the ncache atexit
+	 * handler is called.
+	 * TODO: Implement SEXP_libinit() and call it from oscap_init()?
+	 */
+	volatile SEXP_t *exp = SEXP_string_new("magic", 5);
+	SEXP_free((SEXP_t *)exp);
+
         ncache_libinit();
         oval_probe_tblinit();
 }
@@ -121,7 +134,7 @@ oval_probe_session_t *oval_probe_session_new(struct oval_syschar_model *model)
 
         __init_once();
 
-        dI("__probe_meta_count = %zu\n", OSCAP_GSYM(__probe_meta_count));
+        dD("__probe_meta_count = %zu", OSCAP_GSYM(__probe_meta_count));
 
         for (i = 0; i < OSCAP_GSYM(__probe_meta_count); ++i) {
                 handler_arg = NULL;
@@ -141,7 +154,7 @@ oval_probe_session_t *oval_probe_session_new(struct oval_syschar_model *model)
 void oval_probe_session_destroy(oval_probe_session_t *sess)
 {
 	if (sess == NULL) {
-		dE("Invalid session (NULL)\n");
+		dE("Invalid session (NULL)");
 		return;
 	}
 
@@ -161,7 +174,7 @@ int oval_probe_session_reset(oval_probe_session_t *sess, struct oval_syschar_mod
         oval_ph_t *ph;
 
         if ((ph = oval_probe_handler_get(sess->ph, OVAL_SUBTYPE_ALL)) == NULL) {
-		dE("No probe handler for OVAL_SUBTYPE_ALL\n");
+		dE("No probe handler for OVAL_SUBTYPE_ALL");
 		return (-1);
 	}
 
@@ -179,7 +192,7 @@ int oval_probe_session_abort(oval_probe_session_t *sess)
 	oval_ph_t *ph;
 
 	if ((ph = oval_probe_handler_get(sess->ph, OVAL_SUBTYPE_ALL) ) == NULL) {
-		dE("No probe handler for OVAL_SUBTYPE_ALL\n");
+		dE("No probe handler for OVAL_SUBTYPE_ALL");
 		return (-1);
 	}
 
@@ -188,14 +201,14 @@ int oval_probe_session_abort(oval_probe_session_t *sess)
 
 int oval_probe_session_sethandler(oval_probe_session_t *sess, oval_subtype_t type, oval_probe_handler_t handler, void *ptr)
 {
-	dE("Operation not supported\n");
+	dE("Operation not supported");
         return(-1);
 }
 
 struct oval_syschar_model *oval_probe_session_getmodel(oval_probe_session_t *sess)
 {
 	if (sess == NULL) {
-		dE("Invalid session (NULL)\n");
+		dE("Invalid session (NULL)");
 		return (NULL);
 	}
 
