@@ -40,6 +40,7 @@
 #include "oval_agent_api_impl.h"
 #include "common/util.h"
 #include "common/debug_priv.h"
+#include "common/elements.h"
 
 typedef struct oval_sysint {
 	struct oval_syschar_model *model;
@@ -182,13 +183,13 @@ static int _oval_sysint_parse_tag(xmlTextReaderPtr reader, struct oval_parser_co
 
 	int is_ovalsys = strcmp((const char *)OVAL_SYSCHAR_NAMESPACE, namespace) == 0;
 	if (is_ovalsys && (strcmp(tagname, "interface_name") == 0)) {
-		return_code = oval_parser_text_value(reader, context, &oval_consume_interface_name, sysint);
+		return_code = oscap_parser_text_value(reader, &oval_consume_interface_name, sysint);
 	} else if (is_ovalsys && (strcmp(tagname, "ip_address") == 0)) {
-		return_code = oval_parser_text_value(reader, context, &oval_consume_ip_address, sysint);
+		return_code = oscap_parser_text_value(reader, &oval_consume_ip_address, sysint);
 	} else if (is_ovalsys && (strcmp(tagname, "mac_address") == 0)) {
-		return_code = oval_parser_text_value(reader, context, &oval_consume_mac_address, sysint);
+		return_code = oscap_parser_text_value(reader, &oval_consume_mac_address, sysint);
 	} else {
-		dW("Skipping tag: <%s:%s>.\n", namespace, tagname);
+		dW("Skipping tag: <%s:%s>.", namespace, tagname);
 		oval_parser_skip_tag(reader, context);
 	}
 
@@ -212,7 +213,7 @@ int oval_sysint_parse_tag(xmlTextReaderPtr reader,
 	if (is_ovalsys && (strcmp(tagname, "interface") == 0)) {
 		return_code = oval_parser_parse_tag(reader, context, &_oval_sysint_parse_tag, sysint);
 	} else {
-		dW("Skipping tag: <%s:%s>.\n", namespace, tagname);
+		dW("Skipping tag: <%s:%s>.", namespace, tagname);
 		oval_parser_skip_tag(reader, context);
 	}
 
