@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright 2009-2010 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2013 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -37,10 +37,11 @@
 
 #include "public/oval_types.h"
 #include "oval_definitions_impl.h"
-#include "oval_collection_impl.h"
+#include "adt/oval_collection_impl.h"
 #include "oval_agent_api_impl.h"
 #include "common/util.h"
 #include "common/debug_priv.h"
+#include "common/elements.h"
 #include "common/_error.h"
 
 typedef struct oval_test {
@@ -316,7 +317,7 @@ static void _oval_test_parse_notes_consumer(char *text, void *test)
 static int _oval_test_parse_notes(xmlTextReaderPtr reader, struct oval_parser_context *context, void *user)
 {
 	struct oval_test *test = (struct oval_test *)user;
-	return oval_parser_text_value(reader, context, &_oval_test_parse_notes_consumer, test);
+	return oscap_parser_text_value(reader, &_oval_test_parse_notes_consumer, test);
 }
 
 static int _oval_test_parse_tag(xmlTextReaderPtr reader, struct oval_parser_context *context, void *user)
@@ -345,7 +346,7 @@ static int _oval_test_parse_tag(xmlTextReaderPtr reader, struct oval_parser_cont
 			state_ref = NULL;
 		}
 	} else {
-		oscap_dlprintf(DBG_W, "Skipping tag <%s>.\n", tagname);
+		dW("Skipping tag <%s>.", tagname);
 		return_code = oval_parser_skip_tag(reader, context);
 	}
 
@@ -362,6 +363,10 @@ int oval_test_parse_tag(xmlTextReaderPtr reader, struct oval_parser_context *con
 	struct oval_definition_model *model = context->definition_model;
 
 	char *id = (char *)xmlTextReaderGetAttribute(reader, BAD_CAST "id");
+        if (id == NULL) {
+		oscap_seterr(OSCAP_EFAMILY_OVAL, "Found test element without id attribute.");
+		return -1;
+	}
 	struct oval_test *test = oval_definition_model_get_new_test(model, id);
 
 	oval_subtype_t subtype = oval_subtype_parse(reader);
@@ -378,7 +383,7 @@ int oval_test_parse_tag(xmlTextReaderPtr reader, struct oval_parser_context *con
 	oval_check_t check = oval_check_parse(reader, "check", OVAL_CHECK_UNKNOWN);
 	if (check == OVAL_CHECK_NONE_EXIST) {
 		dW("The 'none exist' CheckEnumeration value has been deprecated. "
-		   "Converted to check='none satisfy' and check_existence='none exist'.\n");
+		   "Converted to check='none satisfy' and check_existence='none exist'.");
 		oval_test_set_check(test, OVAL_CHECK_NONE_SATISFY);
 		oval_test_set_existence(test, OVAL_NONE_EXIST);
 	} else {
@@ -398,7 +403,9 @@ int oval_test_parse_tag(xmlTextReaderPtr reader, struct oval_parser_context *con
 	oval_test_set_deprecated(test, deprecated);
 
 	version = (char *)xmlTextReaderGetAttribute(reader, BAD_CAST "version");
-	oval_test_set_version(test, atoi(version));
+	if (version != NULL) {
+		oval_test_set_version(test, atoi(version));
+	}
 
 
 	ret = oval_parser_parse_tag(reader, context, &_oval_test_parse_tag, test);
@@ -418,7 +425,7 @@ xmlNode *oval_test_to_dom(struct oval_test *test, xmlDoc * doc, xmlNode * parent
 	/* skip unknown test */
 	oval_subtype_t subtype = oval_test_get_subtype(test);
 	if ( subtype == OVAL_SUBTYPE_UNKNOWN ) {
-		oscap_dlprintf(DBG_E, "Unknown Test %s.\n", oval_test_get_id(test));
+		dE("Unknown Test %s.", oval_test_get_id(test));
 		return test_node;
 	}
 
@@ -427,14 +434,10 @@ xmlNode *oval_test_to_dom(struct oval_test *test, xmlDoc * doc, xmlNode * parent
 	char test_name[strlen(subtype_text) + 6];
 	sprintf(test_name, "%s_test", subtype_text);
 
-	/* get family URI */
 	oval_family_t family = oval_test_get_family(test);
-	const char *family_text = oval_family_get_text(family);
-	char family_uri[strlen((const char *)OVAL_DEFINITIONS_NAMESPACE) + strlen(family_text) + 2];
-	sprintf(family_uri,"%s#%s", OVAL_DEFINITIONS_NAMESPACE, family_text);
 
 	/* search namespace & create child */
-	xmlNs *ns_family = xmlSearchNsByHref(doc, parent, BAD_CAST family_uri);
+	xmlNs *ns_family = oval_family_to_namespace(family, (const char *) OVAL_DEFINITIONS_NAMESPACE, doc, parent);
 	test_node = xmlNewTextChild(parent, ns_family, BAD_CAST test_name, NULL);
 
 	char *id = oval_test_get_id(test);
