@@ -188,8 +188,8 @@ static int _oval_variable_model_parse_variable_values
 	char *tagname = (char *)xmlTextReaderLocalName(reader);
 	char *namespace = (char *)xmlTextReaderNamespaceUri(reader);
 	int return_code;
-	bool is_variable_ns = strcmp(NAMESPACE_VARIABLES, namespace) == 0;
-	if (is_variable_ns && strcmp("value", tagname) == 0) {
+	bool is_variable_ns = oscap_strcmp(NAMESPACE_VARIABLES, namespace) == 0;
+	if (is_variable_ns && oscap_strcmp("value", tagname) == 0) {
 		struct oval_value *ov;
 
 		return_code = xmlTextReaderRead(reader);
@@ -198,7 +198,7 @@ static int _oval_variable_model_parse_variable_values
 		oval_collection_add(frame->values, ov);
 		oscap_free(value);
 	} else {
-		oscap_dlprintf(DBG_W, "Unprocessed tag: <%s:%s>.\n", namespace, tagname);
+		dW("Unprocessed tag: <%s:%s>.", namespace, tagname);
 		oval_parser_skip_tag(reader, context);
 		return_code = 0;
 	}
@@ -216,7 +216,7 @@ static int _oval_variable_model_parse_variable
 	int return_code = 1;
 	if (frame) {
 		if (frame->datatype != datatype) {
-			oscap_dlprintf(DBG_W, "Unmatched variable datatypes: %s:%s.\n",
+			dW("Unmatched variable datatypes: %s:%s.",
 				      oval_datatype_get_text(frame->datatype), oval_datatype_get_text(datatype));
 			oval_parser_skip_tag(reader, context);
 			return_code = 0;
@@ -238,11 +238,11 @@ static int _oval_variable_model_parse_variables
 	char *tagname = (char *)xmlTextReaderLocalName(reader);
 	char *namespace = (char *)xmlTextReaderNamespaceUri(reader);
 	int return_code;
-	bool is_variable_ns = strcmp(NAMESPACE_VARIABLES, namespace) == 0;
-	if (is_variable_ns && strcmp("variable", tagname) == 0) {
+	bool is_variable_ns = oscap_strcmp(NAMESPACE_VARIABLES, namespace) == 0;
+	if (is_variable_ns && oscap_strcmp("variable", tagname) == 0) {
 		return_code = _oval_variable_model_parse_variable(reader, context, model);
 	} else {
-		oscap_dlprintf(DBG_W, "Unprocessed tag: <%s:%s>.\n", namespace, tagname);
+		dW("Unprocessed tag: <%s:%s>.", namespace, tagname);
 		oval_parser_skip_tag(reader, context);
 
 		/*oscap_seterr */
@@ -258,17 +258,17 @@ static int _oval_variable_model_parse_tag
 	char *tagname = (char *)xmlTextReaderLocalName(reader);
 	char *namespace = (char *)xmlTextReaderNamespaceUri(reader);
 	int return_code;
-	bool is_variable_ns = strcmp(NAMESPACE_VARIABLES, namespace) == 0;
-	if (is_variable_ns && strcmp("generator", tagname) == 0) {
+	bool is_variable_ns = oscap_strcmp(NAMESPACE_VARIABLES, namespace) == 0;
+	if (is_variable_ns && oscap_strcmp("generator", tagname) == 0) {
 		struct oval_generator *gen;
 
 		gen = oval_variable_model_get_generator(context->variable_model);
 		return_code = oval_generator_parse_tag(reader, context, gen);
-	} else if (is_variable_ns && strcmp("variables", tagname) == 0) {
+	} else if (is_variable_ns && oscap_strcmp("variables", tagname) == 0) {
 		return_code =
 		    oval_parser_parse_tag(reader, context, (oval_xml_tag_parser) _oval_variable_model_parse_variables, model);
 	} else {
-		oscap_dlprintf(DBG_W, "Unprocessed tag: <%s:%s>.\n", namespace, tagname);
+		dW("Unprocessed tag: <%s:%s>.", namespace, tagname);
 		oval_parser_skip_tag(reader, context);
 		return_code = 0;
 	}
@@ -286,12 +286,12 @@ static int _oval_variable_model_parse(struct oval_variable_model *model, xmlText
 	context.user_data = user_param;
 	char *tagname = (char *)xmlTextReaderLocalName(reader);
 	char *namespace = (char *)xmlTextReaderNamespaceUri(reader);
-	bool is_variables = (strcmp(NAMESPACE_VARIABLES, namespace) == 0) && (strcmp(OVAL_ROOT_ELM_VARIABLES, tagname) == 0);
+	bool is_variables = (oscap_strcmp(NAMESPACE_VARIABLES, namespace) == 0) && (oscap_strcmp(OVAL_ROOT_ELM_VARIABLES, tagname) == 0);
 	if (is_variables) {
 		return_code =
 		    oval_parser_parse_tag(reader, &context, (oval_xml_tag_parser) _oval_variable_model_parse_tag, model);
 	} else {
-		oscap_dlprintf(DBG_W, "Unprocessed tag: <%s:%s>.\n", namespace, tagname);
+		dW("Unprocessed tag: <%s:%s>.", namespace, tagname);
 		return_code = oval_parser_skip_tag(reader, &context);
 	}
 	oscap_free(tagname);
@@ -403,7 +403,7 @@ bool oval_variable_model_has_variable(struct oval_variable_model *model, const c
         __attribute__nonnull__(model);
         struct oval_string_iterator * str_it = (struct oval_string_iterator *)oval_string_map_keys(model->varmap);
         while (oval_string_iterator_has_more(str_it)) {
-            if (!strcmp(oval_string_iterator_next(str_it), id)) {
+            if (!oscap_strcmp(oval_string_iterator_next(str_it), id)) {
                 oval_string_iterator_free(str_it);
                 return true;
             }
