@@ -39,6 +39,7 @@
 #include <signal.h>
 #include <fcntl.h>
 #include <common/assume.h>
+#include <common/_error.h>
 #include <errno.h>
 
 #include "generic/common.h"
@@ -168,12 +169,17 @@ static int check_child (pid_t pid, int waitf)
         case -1: return (-1);
         default:
                 /* child is dead */
+		if (WIFSIGNALED(status)) {
+			oscap_seterr(OSCAP_EFAMILY_OVAL, "Probe with PID=%ld has been killed with signal %d", (long)pid, WTERMSIG(status));
+			errno = EINTR;
+		}
+		if (WCOREDUMP(status)) {
+			oscap_seterr(OSCAP_EFAMILY_OVAL, "Probe with PID=%ld has core dumped.", (long)pid);
+			errno = EINTR;
+		}
                 if (WIFEXITED(status)) {
                         errno = WEXITSTATUS(status);
                 }
-                if (WIFSIGNALED(status)) {
-                        errno = EINTR;
-                }
         }
         return (1);
 }
