@@ -48,12 +48,8 @@ int SEXP_val_new (SEXP_val_t *dst, size_t vmemsize, SEXP_type_t type)
         dst->type      = type;
         dst->ptr       = SEXP_val_ptr (dst);
 #if defined(SEAP_VERBOSE_DEBUG)
-        dI("\n"
-           "new value: hdr->refs = %u\n"
-           "           hdr->size = %zu\n"
-           "                type = %hhu\n"
-           "                 ptr = %p\n",
-           dst->hdr->refs, dst->hdr->size, dst->type, (void *)dst->ptr);
+	dD("new value: hdr->refs = %u, hdr->size = %zu, type = %hhu, ptr = %p",
+		dst->hdr->refs, dst->hdr->size, dst->type, (void *)dst->ptr);
 #endif
         return (0);
 }
