@@ -427,7 +427,7 @@ SEXP_t *probe_obj_getent(const SEXP_t * obj, const char *name, uint32_t n)
 #if !defined(NDEBUG) && defined(SEAP_VERBOSE_DEBUG)
 			char buf[128];
 			SEXP_string_cstr_r(ent_name, buf, sizeof buf);
-			dI("1=\"%s\", 2=\"%s\", n=%u\n", buf, name, n);
+			dI("1=\"%s\", 2=\"%s\", n=%u", buf, name, n);
 #endif
 
 			if (SEXP_strcmp(ent_name, name) == 0 && (--n == 0)) {
@@ -470,49 +470,60 @@ int probe_obj_getentvals(const SEXP_t * obj, const char *name, uint32_t n, SEXP_
 }
 
 oval_version_t probe_obj_get_schema_version(const SEXP_t *obj)
+{
+	oval_schema_version_t version = probe_obj_get_platform_schema_version(obj);
+	const char *version_str = oval_schema_version_to_cstr(version);
+	oval_version_t old_version_format = oval_version_from_cstr(version_str);
+	oscap_free(version_str);
+	return old_version_format;
+}
+
+oval_schema_version_t probe_obj_get_platform_schema_version(const SEXP_t *obj)
 {
 	SEXP_t *sexp_ver;
-	oval_version_t ver;
 
 	if (obj == NULL)
-		return OVAL_VERSION_INVALID;
+		return OVAL_SCHEMA_VERSION_INVALID;
 	sexp_ver = probe_obj_getattrval(obj, "oval_version");
 
-	if (!SEXP_numberp(sexp_ver)) {
+	if (!SEXP_stringp(sexp_ver)) {
 		SEXP_free(sexp_ver);
-		return OVAL_VERSION_INVALID;
+		return OVAL_SCHEMA_VERSION_INVALID;
 	}
 
-	ver = SEXP_number_getu_32(sexp_ver);
+	char *ver = SEXP_string_cstr(sexp_ver);
 	SEXP_free(sexp_ver);
-
-	return ver;
+	oval_schema_version_t parsed_version = oval_schema_version_from_cstr(ver);
+	oscap_free(ver);
+	return parsed_version;
 }
 
+
+
 SEXP_t *probe_obj_getattrval(const SEXP_t * obj, const char *name)
 {
 	SEXP_t *obj_name;
-	char name_buf[64 + 1];
-	size_t name_len;
 
 	obj_name = SEXP_list_first(obj);
-	name_len = snprintf(name_buf, sizeof name_buf, ":%s", name);
-
-	_A(name_len < sizeof name_buf);
 
 	if (SEXP_listp(obj_name)) {
 		uint32_t i;
 		SEXP_t *attr;
+		char *name_buf = NULL;
 
 		i = 2;
 
 		while ((attr = SEXP_list_nth(obj_name, i)) != NULL) {
 			if (SEXP_stringp(attr)) {
 				if (SEXP_string_nth(attr, 1) == ':') {
+					if (name_buf == NULL) {
+						name_buf = oscap_sprintf(":%s", name);
+					}
 					if (SEXP_strcmp(attr, name_buf) == 0) {
 						SEXP_t *val;
 
 						val = SEXP_list_nth(obj_name, i + 1);
+						oscap_free(name_buf);
 						SEXP_free(attr);
 						SEXP_free(obj_name);
 
@@ -527,6 +538,7 @@ SEXP_t *probe_obj_getattrval(const SEXP_t * obj, const char *name)
 
 			SEXP_free(attr);
 		}
+		oscap_free(name_buf);
 	}
 
 	SEXP_free(obj_name);
@@ -537,24 +549,23 @@ SEXP_t *probe_obj_getattrval(const SEXP_t * obj, const char *name)
 bool probe_obj_attrexists(const SEXP_t * obj, const char *name)
 {
 	SEXP_t *obj_name;
-	char name_buf[64 + 1];
-	size_t name_len;
-
 	obj_name = SEXP_list_first(obj);
-	name_len = snprintf(name_buf, sizeof name_buf, ":%s", name);
-
-	_A(name_len < sizeof name_buf);
 
 	if (SEXP_listp(obj_name)) {
 		uint32_t i;
 		SEXP_t *attr;
+		char *name_buf = NULL;
 
 		i = 2;
 
 		while ((attr = SEXP_list_nth(obj_name, i)) != NULL) {
 			if (SEXP_stringp(attr)) {
 				if (SEXP_string_nth(attr, 1) == ':') {
+					if (name_buf == NULL) {
+						name_buf = oscap_sprintf(":%s", name);
+					}
 					if (SEXP_strcmp(attr, name_buf) == 0) {
+						oscap_free(name_buf);
 						SEXP_free(attr);
 						SEXP_free(obj_name);
 
@@ -562,7 +573,8 @@ bool probe_obj_attrexists(const SEXP_t * obj, const char *name)
 					}
 					++i;
 				} else {
-                                    if (SEXP_strcmp(attr, name_buf + 1) == 0) {
+					if (SEXP_strcmp(attr, name) == 0) {
+						oscap_free(name_buf);
                                         SEXP_free(attr);
                                         SEXP_free(obj_name);
                                         return true;
@@ -573,6 +585,7 @@ bool probe_obj_attrexists(const SEXP_t * obj, const char *name)
 
 			SEXP_free(attr);
 		}
+		oscap_free(name_buf);
 	}
 
 	SEXP_free(obj_name);
@@ -670,7 +683,7 @@ void probe_cobj_set_flag(SEXP_t *cobj, oval_syschar_collection_flag_t flag)
 	of = SEXP_number_getu(old_sflag);
 	SEXP_free(old_sflag);
 	SEXP_free(sflag);
-	dI("old flag: %d, new flag: %d.\n", of, flag);
+	dI("old flag: %d, new flag: %d.", of, flag);
 }
 
 oval_syschar_collection_flag_t probe_cobj_get_flag(const SEXP_t *cobj)
@@ -680,7 +693,7 @@ oval_syschar_collection_flag_t probe_cobj_get_flag(const SEXP_t *cobj)
 
 	sflag = SEXP_list_first(cobj);
 	if (sflag == NULL) {
-		dE("sflag == NULL.\n");
+		dE("sflag == NULL.");
 		return SYSCHAR_FLAG_UNKNOWN;
 	}
 
@@ -906,7 +919,7 @@ SEXP_t *probe_msg_creat(oval_message_level_t level, char *message)
 {
 	SEXP_t *lvl, *str, *msg;
 
-	dI("%s\n", message);
+	dI("%s", message);
 	lvl = SEXP_number_newu(level);
 	str = SEXP_string_newf("%s", message);
 	msg = SEXP_list_new(lvl, str, NULL);
@@ -928,7 +941,7 @@ SEXP_t *probe_msg_creatf(oval_message_level_t level, const char *fmt, ...)
 	if (len < 0)
 		return NULL;
 
-	dI("%s\n", cstr);
+	dI("%s", cstr);
 	str = SEXP_string_new(cstr, len);
 	oscap_free(cstr);
 	lvl = SEXP_number_newu(level);
@@ -1133,7 +1146,7 @@ static oval_datatype_t _sexp_val_getdatatype(const SEXP_t *val)
 			return OVAL_DATATYPE_INTEGER;
 		}
 	default:
-		dE("Unexpected SEXP datatype: %d, '%s'.\n", sdt, SEXP_strtype(val));
+		dE("Unexpected SEXP datatype: %d, '%s'.", sdt, SEXP_strtype(val));
 		return OVAL_DATATYPE_UNKNOWN;
 	}
 }
@@ -1395,7 +1408,7 @@ SEXP_t *probe_item_create(oval_subtype_t item_subtype, probe_elmatr_t *item_attr
         subtype_name = oval_subtype_to_str(item_subtype);
 
         if (subtype_name == NULL) {
-                dE("Invalid/Unknown subtype: %d\n", (int)item_subtype);
+                dE("Invalid/Unknown subtype: %d", (int)item_subtype);
                 return (NULL);
         }
 
@@ -1404,7 +1417,7 @@ SEXP_t *probe_item_create(oval_subtype_t item_subtype, probe_elmatr_t *item_attr
                 strcat(item_name, "_item");
                 item_name[sizeof item_name - 1] = '\0';
         } else {
-                dE("item name too long: no buffer space available\n");
+                dE("item name too long: no buffer space available");
                 return (NULL);
         }
 
@@ -1474,6 +1487,7 @@ SEXP_t *probe_item_create(oval_subtype_t item_subtype, probe_elmatr_t *item_attr
 			SEXP_list_add(item, entity);
 			goto skip;
                 case OVAL_DATATYPE_EVR_STRING:
+                case OVAL_DATATYPE_DEBIAN_EVR_STRING:
                 case OVAL_DATATYPE_FILESET_REVISION:
                 case OVAL_DATATYPE_IOS_VERSION:
 		case OVAL_DATATYPE_IPV4ADDR:
@@ -1486,7 +1500,7 @@ SEXP_t *probe_item_create(oval_subtype_t item_subtype, probe_elmatr_t *item_attr
                         /* TODO */
                 case OVAL_DATATYPE_BINARY:
                 case OVAL_DATATYPE_UNKNOWN:
-			dE("Unknown or unsupported OVAL datatype: %d, '%s', name: '%s'.\n",
+			dE("Unknown or unsupported OVAL datatype: %d, '%s', name: '%s'.",
 			   value_type, oval_datatype_get_text(value_type), value_name);
                         SEXP_free(item);
 
@@ -1546,19 +1560,19 @@ oval_operation_t probe_ent_getoperation(SEXP_t *entity, oval_operation_t default
         SEXP_t *aval;
 
         if (entity == NULL) {
-                dW("entity == NULL\n");
+                dW("entity == NULL");
                 return (OVAL_OPERATION_UNKNOWN);
         }
 
         aval = probe_ent_getattrval(entity, "operation");
 
         if (aval == NULL) {
-                dW("Attribute \"operation\" not found. Using default.\n");
+                dW("Attribute \"operation\" not found. Using default.");
                 return (default_op);
         }
 
         if (!SEXP_numberp(aval)) {
-                dW("Invalid type\n");
+                dW("Invalid type");
                 SEXP_free(aval);
                 return (OVAL_OPERATION_UNKNOWN);
         }
@@ -1582,13 +1596,13 @@ int probe_item_add_msg(SEXP_t *item, oval_message_level_t msglvl, char *msgfmt,
     msg_length = vsnprintf(msg_buffer, sizeof msg_buffer, msgfmt, ap);
 
     if (msg_length < 0) {
-	dE("vsnprintf failed! errno=%u, %s.\n", errno, strerror(errno));
+	dE("vsnprintf failed! errno=%u, %s.", errno, strerror(errno));
 	va_end(ap);
 	return (-1);
     }
 
     if ((size_t)msg_length >= sizeof msg_buffer) {
-	dE("message too long!\n");
+	dE("message too long!");
 	va_end(ap);
 	return (-1);
     }
@@ -1679,6 +1693,7 @@ SEXP_t *probe_entval_from_cstr(oval_datatype_t type,
 	}	break;
 
 	case OVAL_DATATYPE_EVR_STRING:
+	case OVAL_DATATYPE_DEBIAN_EVR_STRING:
 	case OVAL_DATATYPE_FILESET_REVISION:
 	case OVAL_DATATYPE_IOS_VERSION:
 	case OVAL_DATATYPE_STRING:
