@@ -61,14 +61,14 @@ static void probe_icache_item_setID(SEXP_t *item, SEXP_ID_t item_ID)
         local_id = __sync_fetch_and_add(&next_ID, 1);
 #else
         if (pthread_mutex_lock(&next_ID_mutex) != 0) {
-                dE("Can't lock the next_ID_mutex: %u, %s\n", errno, strerror(errno));
+                dE("Can't lock the next_ID_mutex: %u, %s", errno, strerror(errno));
                 abort();
         }
 
         local_id = ++next_ID;
 
         if (pthread_mutex_unlock(&next_ID_mutex) != 0) {
-                dE("Can't unlock the next_ID_mutex: %u, %s\n", errno, strerror(errno));
+                dE("Can't unlock the next_ID_mutex: %u, %s", errno, strerror(errno));
                 abort();
         }
 #endif
@@ -92,14 +92,16 @@ static void *probe_icache_worker(void *arg)
 
         assume_d(cache != NULL, NULL);
 
+	pthread_setname_np(pthread_self(), "icache_worker");
+
         if (pthread_mutex_lock(&cache->queue_mutex) != 0) {
-                dE("An error ocured while locking the queue mutex: %u, %s\n",
+                dE("An error ocured while locking the queue mutex: %u, %s",
                    errno, strerror(errno));
                 return (NULL);
         }
 
 	pair = &pair_mem;
-        dI("icache worker ready\n");
+        dD("icache worker ready");
 
         switch (errno = pthread_barrier_wait(&OSCAP_GSYM(th_barrier)))
         {
@@ -107,7 +109,7 @@ static void *probe_icache_worker(void *arg)
         case PTHREAD_BARRIER_SERIAL_THREAD:
 	        break;
         default:
-	        dE("pthread_barrier_wait: %d, %s.\n",
+	        dE("pthread_barrier_wait: %d, %s.",
 	           errno, strerror(errno));
 	        pthread_mutex_unlock(&cache->queue_mutex);
 	        return (NULL);
@@ -116,7 +118,7 @@ static void *probe_icache_worker(void *arg)
         while(pthread_cond_wait(&cache->queue_notempty, &cache->queue_mutex) == 0) {
                 assume_d(cache->queue_cnt > 0, NULL);
         next:
-                dI("Extracting item from the cache queue: cnt=%"PRIu16", beg=%"PRIu16"\n", cache->queue_cnt, cache->queue_beg);
+                dD("Extracting item from the cache queue: cnt=%"PRIu16", beg=%"PRIu16"", cache->queue_cnt, cache->queue_beg);
                 /*
                  * Extract an item from the queue and update queue beg, end & cnt
                  */
@@ -138,15 +140,15 @@ static void *probe_icache_worker(void *arg)
                  * Release the mutex
                  */
                 if (pthread_mutex_unlock(&cache->queue_mutex) != 0) {
-                        dE("An error ocured while unlocking the queue mutex: %u, %s\n",
+                        dE("An error ocured while unlocking the queue mutex: %u, %s",
                            errno, strerror(errno));
                         abort();
                 }
 
-                dI("Signaling `notfull'\n");
+                dD("Signaling `notfull'");
 
                 if (pthread_cond_signal(&cache->queue_notfull) != 0) {
-                        dE("An error ocured while signaling the `notfull' condition: %u, %s\n",
+                        dE("An error ocured while signaling the `notfull' condition: %u, %s",
                            errno, strerror(errno));
                         abort();
                 }
@@ -157,23 +159,23 @@ static void *probe_icache_worker(void *arg)
                          */
                         assume_d(pair->p.cond != NULL, NULL);
 
-                        dI("Handling NOP\n");
+                        dD("Handling NOP");
 
                         if (pthread_cond_signal(pair->p.cond) != 0) {
-                                dE("An error ocured while signaling NOP condition: %u, %s\n",
+                                dE("An error ocured while signaling NOP condition: %u, %s",
                                    errno, strerror(errno));
                                 abort();
                         }
                 } else {
                         probe_citem_t *cached = NULL;
 
-                        dI("Handling cache request\n");
+                        dD("Handling cache request");
 
                         /*
                          * Compute item ID
                          */
                         item_ID = SEXP_ID_v(pair->p.item);
-                        dI("item ID=%"PRIu64"\n", item_ID);
+                        dD("item ID=%"PRIu64"", item_ID);
 
                         /*
                          * Perform cache lookup
@@ -184,7 +186,7 @@ static void *probe_icache_worker(void *arg)
                                 /*
                                  * Maybe a cache HIT
                                  */
-                                dI("cache HIT #1\n");
+                                dD("cache HIT #1");
 
                                 for (i = 0; i < cached->count; ++i) {
                                         if (SEXP_deepcmp(SEXP_list_rest_r(&rest1, pair->p.item),
@@ -203,7 +205,7 @@ static void *probe_icache_worker(void *arg)
                                         /*
                                          * Cache MISS
                                          */
-                                        dI("cache MISS\n");
+                                        dD("cache MISS");
 
                                         cached->item = oscap_realloc(cached->item, sizeof(SEXP_t *) * ++cached->count);
                                         cached->item[cached->count - 1] = pair->p.item;
@@ -214,7 +216,7 @@ static void *probe_icache_worker(void *arg)
                                         /*
                                          * Cache HIT
                                          */
-                                        dI("cache HIT #2 -> real HIT\n");
+                                        dD("cache HIT #2 -> real HIT");
                                         SEXP_free(pair->p.item);
                                         pair->p.item = cached->item[i];
                                 }
@@ -222,7 +224,7 @@ static void *probe_icache_worker(void *arg)
                                 /*
                                  * Cache MISS
                                  */
-                                dI("cache MISS\n");
+                                dD("cache MISS");
                                 cached = oscap_talloc(probe_citem_t);
                                 cached->item = oscap_talloc(SEXP_t *);
                                 cached->item[0] = pair->p.item;
@@ -232,7 +234,7 @@ static void *probe_icache_worker(void *arg)
                                 probe_icache_item_setID(pair->p.item, item_ID);
 
                                 if (rbt_i64_add(cache->tree, (int64_t)item_ID, (void *)cached, NULL) != 0) {
-                                        dE("Can't add item (k=%"PRIi64" to the cache (%p)\n", (int64_t)item_ID, cache->tree);
+                                        dE("Can't add item (k=%"PRIi64" to the cache (%p)", (int64_t)item_ID, cache->tree);
 
                                         oscap_free(cached->item);
                                         oscap_free(cached);
@@ -243,12 +245,12 @@ static void *probe_icache_worker(void *arg)
                         }
 
                         if (probe_cobj_add_item(pair->cobj, pair->p.item) != 0) {
-                            dW("An error ocured while adding the item to the collected object\n");
+                            dW("An error ocured while adding the item to the collected object");
                         }
                 }
 
                 if (pthread_mutex_lock(&cache->queue_mutex) != 0) {
-                        dE("An error ocured while re-locking the queue mutex: %u, %s\n",
+                        dE("An error ocured while re-locking the queue mutex: %u, %s",
                            errno, strerror(errno));
                         abort();
                 }
@@ -268,7 +270,7 @@ probe_icache_t *probe_icache_new(void)
         cache->tree = rbt_i64_new();
 
         if (pthread_mutex_init(&cache->queue_mutex, NULL) != 0) {
-                dE("Can't initialize icache mutex: %u, %s\n", errno, strerror(errno));
+                dE("Can't initialize icache mutex: %u, %s", errno, strerror(errno));
                 goto fail;
         }
 
@@ -278,13 +280,13 @@ probe_icache_t *probe_icache_new(void)
         cache->queue_max = PROBE_IQUEUE_CAPACITY;
 
         if (pthread_cond_init(&cache->queue_notempty, NULL) != 0) {
-                dE("Can't initialize icache queue condition variable (notempty): %u, %s\n",
+                dE("Can't initialize icache queue condition variable (notempty): %u, %s",
                    errno, strerror(errno));
                 goto fail;
         }
 
         if (pthread_cond_init(&cache->queue_notfull, NULL) != 0) {
-                dE("Can't initialize icache queue condition variable (notfull): %u, %s\n",
+                dE("Can't initialize icache queue condition variable (notfull): %u, %s",
                    errno, strerror(errno));
                 goto fail;
         }
@@ -292,7 +294,7 @@ probe_icache_t *probe_icache_new(void)
         if (pthread_create(&cache->thid, NULL,
                            probe_icache_worker, (void *)cache) != 0)
         {
-                dE("Can't start the icache worker: %u, %s\n", errno, strerror(errno));
+                dE("Can't start the icache worker: %u, %s", errno, strerror(errno));
                 goto fail;
         }
 
@@ -335,7 +337,7 @@ retry:
                 if (pthread_cond_wait(&cache->queue_notfull, &cache->queue_mutex) == 0)
                         goto retry;
                 else {
-                        dE("An error ocured while waiting for the `notfull' queue condition: %u, %s\n",
+                        dE("An error ocured while waiting for the `notfull' queue condition: %u, %s",
                            errno, strerror(errno));
                         return (-1);
                 }
@@ -352,7 +354,7 @@ int probe_icache_add(probe_icache_t *cache, SEXP_t *cobj, SEXP_t *item)
                 return (-1); /* XXX: EFAULT */
 
         if (pthread_mutex_lock(&cache->queue_mutex) != 0) {
-                dE("An error ocured while locking the queue mutex: %u, %s\n",
+                dE("An error ocured while locking the queue mutex: %u, %s",
                    errno, strerror(errno));
                 return (-1);
         }
@@ -360,7 +362,7 @@ int probe_icache_add(probe_icache_t *cache, SEXP_t *cobj, SEXP_t *item)
         ret = __probe_icache_add_nolock(cache, cobj, item, NULL);
 
         if (pthread_mutex_unlock(&cache->queue_mutex) != 0) {
-                dE("An error ocured while unlocking the queue mutex: %u, %s\n",
+                dE("An error ocured while unlocking the queue mutex: %u, %s",
                    errno, strerror(errno));
                 abort();
         }
@@ -369,7 +371,7 @@ int probe_icache_add(probe_icache_t *cache, SEXP_t *cobj, SEXP_t *item)
                 return (-1);
 
         if (pthread_cond_signal(&cache->queue_notempty) != 0) {
-                dE("An error ocured while signaling the `notempty' condition: %u, %s\n",
+                dE("An error ocured while signaling the `notempty' condition: %u, %s",
                    errno, strerror(errno));
                 return (-1);
         }
@@ -381,23 +383,23 @@ int probe_icache_nop(probe_icache_t *cache)
 {
         pthread_cond_t cond;
 
-        dI("NOP\n");
+        dD("NOP");
 
         if (pthread_mutex_lock(&cache->queue_mutex) != 0) {
-                dE("An error ocured while locking the queue mutex: %u, %s\n",
+                dE("An error ocured while locking the queue mutex: %u, %s",
                    errno, strerror(errno));
                 return (-1);
         }
 
         if (pthread_cond_init(&cond, NULL) != 0) {
-                dE("Can't initialize icache queue condition variable (NOP): %u, %s\n",
+                dE("Can't initialize icache queue condition variable (NOP): %u, %s",
                    errno, strerror(errno));
                 return (-1);
         }
 
         if (__probe_icache_add_nolock(cache, NULL, NULL, &cond) != 0) {
                 if (pthread_mutex_unlock(&cache->queue_mutex) != 0) {
-                        dE("An error ocured while unlocking the queue mutex: %u, %s\n",
+                        dE("An error ocured while unlocking the queue mutex: %u, %s",
                            errno, strerror(errno));
                         abort();
                 }
@@ -406,28 +408,28 @@ int probe_icache_nop(probe_icache_t *cache)
                 return (-1);
         }
 
-        dI("Signaling `notempty'\n");
+        dD("Signaling `notempty'");
 
         if (pthread_cond_signal(&cache->queue_notempty) != 0) {
-                dE("An error ocured while signaling the `notempty' condition: %u, %s\n",
+                dE("An error ocured while signaling the `notempty' condition: %u, %s",
                    errno, strerror(errno));
 
                 pthread_cond_destroy(&cond);
                 return (-1);
         }
 
-        dI("Waiting for icache worker to handle the NOP\n");
+        dD("Waiting for icache worker to handle the NOP");
 
         if (pthread_cond_wait(&cond, &cache->queue_mutex) != 0) {
-                dE("An error ocured while waiting for the `NOP' queue condition: %u, %s\n",
+                dE("An error ocured while waiting for the `NOP' queue condition: %u, %s",
                    errno, strerror(errno));
                 return (-1);
         }
 
-        dI("Sync\n");
+        dD("Sync");
 
         if (pthread_mutex_unlock(&cache->queue_mutex) != 0) {
-                dE("An error ocured while unlocking the queue mutex: %u, %s\n",
+                dE("An error ocured while unlocking the queue mutex: %u, %s",
                    errno, strerror(errno));
                 abort();
         }
@@ -461,14 +463,14 @@ static int probe_cobj_memcheck(size_t item_cnt)
 		c_ratio = (double)mu_proc.mu_rss/(double)(mu_sys.mu_total);
 
 		if (c_ratio > PROBE_RESULT_MEMCHECK_MAXRATIO) {
-			dW("Memory usage ratio limit reached! limit=%f, current=%f\n",
+			dW("Memory usage ratio limit reached! limit=%f, current=%f",
 			   PROBE_RESULT_MEMCHECK_MAXRATIO, c_ratio);
 			errno = ENOMEM;
 			return (1);
 		}
 
 		if ((mu_sys.mu_realfree / 1024) < PROBE_RESULT_MEMCHECK_MINFREEMEM) {
-			dW("Minimum free memory limit reached! limit=%zu, current=%zu\n",
+			dW("Minimum free memory limit reached! limit=%zu, current=%zu",
 			   PROBE_RESULT_MEMCHECK_MINFREEMEM, mu_sys.mu_realfree / 1024);
 			errno = ENOMEM;
 			return (1);
@@ -539,7 +541,7 @@ int probe_item_collect(struct probe_ctx *ctx, SEXP_t *item)
         }
 
         if (probe_icache_add(ctx->icache, ctx->probe_out, item) != 0) {
-                dE("Can't add item (%p) to the item cache (%p)\n", item, ctx->icache);
+                dE("Can't add item (%p) to the item cache (%p)", item, ctx->icache);
                 SEXP_free(item);
                 return (-1);
         }
