@@ -513,7 +513,7 @@ SEXP_t *probe_item_create(oval_subtype_t item_subtype, probe_elmatr_t *item_attr
 #define PROBE_ENT_AREF(ent, dst, attr_name, invalid_exp)		\
 	do {								\
 		if (((dst) = probe_ent_getattrval(ent, attr_name)) == NULL) { \
-			dE("Attribute `%s' is missing!\n", attr_name);	\
+			dE("Attribute `%s' is missing!", attr_name);	\
 			invalid_exp					\
 		}               					\
 	} while(0)
@@ -523,11 +523,11 @@ SEXP_t *probe_item_create(oval_subtype_t item_subtype, probe_elmatr_t *item_attr
 		SEXP_t *___r;					\
 								\
 		if ((___r = probe_ent_getval(ent)) == NULL) {	\
-			dW("Entity has no value!\n");		\
+			dW("Entity has no value!");		\
 			invalid_exp				\
 		} else {					\
 			if (!SEXP_stringp(___r)) {		\
-				dE("Invalid type\n");		\
+				dE("Invalid type");		\
 				SEXP_free(___r);		\
 				invalid_exp			\
 			}					\
@@ -546,11 +546,11 @@ SEXP_t *probe_item_create(oval_subtype_t item_subtype, probe_elmatr_t *item_attr
 		SEXP_t *___r;					\
 								\
 		if ((___r = probe_ent_getval(ent)) == NULL) {	\
-			dW("Entity has no value!\n");		\
+			dW("Entity has no value!");		\
 			nil_exp;				\
 		} else {					\
 			if (!SEXP_numberp(___r)) {		\
-				dE("Invalid type\n");		\
+				dE("Invalid type");		\
 				SEXP_free(___r);		\
 				invalid_exp;			\
 			} else {				\
@@ -569,7 +569,8 @@ int probe_item_add_msg(SEXP_t *item, oval_message_level_t msglvl, char *msgfmt,
 SEXP_t *probe_entval_from_cstr(oval_datatype_t type, const char *value, size_t vallen);
 SEXP_t *probe_ent_from_cstr(const char *name, oval_datatype_t type, const char *value, size_t vallen);
 
-oval_version_t probe_obj_get_schema_version(const SEXP_t *obj);
+OSCAP_DEPRECATED(oval_version_t probe_obj_get_schema_version(const SEXP_t *obj));
+oval_schema_version_t probe_obj_get_platform_schema_version(const SEXP_t *obj);
 
 /**
  * Get object entity mask
