@@ -49,6 +49,7 @@
 #endif
 
 #define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 #include <stdio.h>
 #include <stdbool.h>
 #include <string.h>
@@ -104,7 +105,7 @@ static int get_runlevel_sysv (struct runlevel_req *req, struct runlevel_rep **re
 
 	init_dir = opendir(init_path);
 	if (init_dir == NULL) {
-		dI("Can't open directory \"%s\": errno=%d, %s.\n",
+		dI("Can't open directory \"%s\": errno=%d, %s.",
 		   init_path, errno, strerror (errno));
 		return (-1);
 	}
@@ -117,14 +118,14 @@ static int get_runlevel_sysv (struct runlevel_req *req, struct runlevel_rep **re
 		// Ensure that we are in the expected directory before
 		// touching relative paths
 		if (fchdir(dirfd(init_dir)) != 0) {
-			dI("Can't fchdir to \"%s\": errno=%d, %s.\n",
+			dI("Can't fchdir to \"%s\": errno=%d, %s.",
 			   init_path, errno, strerror (errno));
 			closedir(init_dir);
 			return -1;
 		}
 
 		if (stat(init_dp->d_name, &init_st) != 0) {
-			dI("Can't stat file %s/%s: errno=%d, %s.\n",
+			dI("Can't stat file %s/%s: errno=%d, %s.",
 			   init_path, init_dp->d_name, errno, strerror(errno));
 			continue;
 		}
@@ -152,12 +153,12 @@ static int get_runlevel_sysv (struct runlevel_req *req, struct runlevel_rep **re
 			snprintf(pathbuf, sizeof (pathbuf), rc_path, runlevel_list[i]);
 			rc_dir = opendir(pathbuf);
 			if (rc_dir == NULL) {
-				dI("Can't open directory \"%s\": errno=%d, %s.\n",
+				dI("Can't open directory \"%s\": errno=%d, %s.",
 				   rc_path, errno, strerror (errno));
 				continue;
 			}
 			if (chdir(pathbuf) != 0) {
-				dI("Can't fchdir to \"%s\": errno=%d, %s.\n",
+				dI("Can't fchdir to \"%s\": errno=%d, %s.",
 				   rc_path, errno, strerror (errno));
 				closedir(rc_dir);
 				continue;
@@ -167,7 +168,7 @@ static int get_runlevel_sysv (struct runlevel_req *req, struct runlevel_rep **re
 
 			while ((rc_dp = readdir(rc_dir)) != NULL) {
 				if (stat(rc_dp->d_name, &rc_st) != 0) {
-					dI("Can't stat file %s/%s: errno=%d, %s.\n",
+					dI("Can't stat file %s/%s: errno=%d, %s.",
 					   rc_path, rc_dp->d_name, errno, strerror(errno));
 					continue;
 				}
@@ -180,7 +181,7 @@ static int get_runlevel_sysv (struct runlevel_req *req, struct runlevel_rep **re
 						kill = true;
 						break;
 					} else {
-						dI("Unexpected character in filename: %c, %s/%s.\n",
+						dI("Unexpected character in filename: %c, %s/%s.",
 						   rc_dp->d_name[0], pathbuf, rc_dp->d_name);
 					}
 				}
@@ -372,7 +373,7 @@ int probe_main (probe_ctx *ctx, void *arg)
 
 	request_st.service_name_ent = probe_obj_getent(object, "service_name", 1);
 	if (request_st.service_name_ent == NULL) {
-		dI("%s: element not found\n", "service_name");
+		dI("%s: element not found", "service_name");
 
 		return PROBE_ENOELM;
 	}
@@ -380,7 +381,7 @@ int probe_main (probe_ctx *ctx, void *arg)
 	request_st.runlevel_ent = probe_obj_getent(object, "runlevel", 1);
 	if (request_st.runlevel_ent == NULL) {
 		SEXP_free(request_st.service_name_ent);
-		dI("%s: element not found\n", "runlevel");
+		dI("%s: element not found", "runlevel");
 
 		return PROBE_ENOELM;
 	}
@@ -397,7 +398,7 @@ int probe_main (probe_ctx *ctx, void *arg)
 		SEXP_t *item;
 
 		while (reply_st != NULL) {
-			dI("get_runlevel: [0]=\"%s\", [1]=\"%s\", [2]=\"%d\", [3]=\"%d\"\n",
+			dI("get_runlevel: [0]=\"%s\", [1]=\"%s\", [2]=\"%d\", [3]=\"%d\"",
 			   reply_st->service_name, reply_st->runlevel, reply_st->start, reply_st->kill);
 
                         item = probe_item_create(OVAL_UNIX_RUNLEVEL, NULL,
