@@ -25,6 +25,11 @@
  * Authors:
  *      "Daniel Kopecek" <dkopecek@redhat.com>
  */
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <probe-api.h>
 #include "probe/entcmp.h"
 
@@ -48,14 +53,21 @@ int probe_main(probe_ctx *ctx, void *probe_arg)
         OVAL_FTSENT *ofts_ent;
 
         SEXP_t *name_entity, *probe_in;
-        SEXP_t *r0, *r1, *r2;
+        SEXP_t *r0, *r1, *r2, *r3;
         SEXP_t *ent_attrs, *bh_entity, *path_entity, *filename_entity;
+        oval_schema_version_t over;
+        int over_cmp;
+
+	const char *ipv6_conf_path = "/proc/sys/net/ipv6/conf/";
+	size_t ipv6_conf_path_len = strlen(ipv6_conf_path);
 
         probe_in    = probe_ctx_getobject(ctx);
         name_entity = probe_obj_getent(probe_in, "name", 1);
+        over        = probe_obj_get_platform_schema_version(probe_in);
+        over_cmp    = oval_schema_version_cmp(over, OVAL_SCHEMA_VERSION(5.10));
 
         if (name_entity == NULL) {
-                dE("Missing \"name\" entity in the input object\n");
+                dE("Missing \"name\" entity in the input object");
                 return (PROBE_ENOENT);
         }
 
@@ -65,15 +77,18 @@ int probe_main(probe_ctx *ctx, void *probe_arg)
         ent_attrs = probe_attr_creat("max_depth",           r0 = SEXP_string_newf("%d", PROC_SYS_MAXDEPTH),
                                      "recurse_direction",   r1 = SEXP_string_new("down", 4),
                                      "recurse_file_system", r2 = SEXP_string_new("defined", 7),
+                                     "recurse", r3 = SEXP_string_new("symlinks and directories", 24),
                                      NULL);
         bh_entity = probe_ent_creat1("behaviors", ent_attrs, NULL);
-        SEXP_vfree(r0, r1, r2, ent_attrs, NULL);
+        SEXP_vfree(r0, r1, r2, r3, ent_attrs, NULL);
 
         /*
          * prepare path, filename
          */
-        path_entity = probe_ent_creat1("path", NULL, r0 = SEXP_string_new(PROC_SYS_DIR, strlen(PROC_SYS_DIR)));
-        SEXP_free(r0);
+        ent_attrs = probe_attr_creat("operation", r0 = SEXP_number_newi(OVAL_OPERATION_EQUALS),
+                                     NULL);
+        path_entity = probe_ent_creat1("path", ent_attrs, r1 = SEXP_string_new(PROC_SYS_DIR, strlen(PROC_SYS_DIR)));
+        SEXP_vfree(r0, r1, NULL);
 
         ent_attrs = probe_attr_creat("operation", r0 = SEXP_number_newi(OVAL_OPERATION_PATTERN_MATCH),
                                      NULL);
@@ -87,7 +102,7 @@ int probe_main(probe_ctx *ctx, void *probe_arg)
         ofts = oval_fts_open(path_entity, filename_entity, NULL, bh_entity);
 
         if (ofts == NULL) {
-                dE("oval_ftp_open(%s, %s) failed\n", PROC_SYS_DIR, ".\\+");
+                dE("oval_ftp_open(%s, %s) failed", PROC_SYS_DIR, ".\\+");
                 SEXP_vfree(path_entity, filename_entity, bh_entity, name_entity, NULL);
 
                 return (PROBE_EFATAL);
@@ -97,9 +112,23 @@ int probe_main(probe_ctx *ctx, void *probe_arg)
                 SEXP_t *se_mib;
                 char    mibpath[PATH_MAX], *mib;
                 size_t  miblen;
+		struct stat file_stat;
 
                 snprintf(mibpath, sizeof mibpath, "%s/%s", ofts_ent->path, ofts_ent->file);
 
+		/* Skip write-only files, eg. /proc/sys/net/ipv4/route/flush */
+		if (stat(mibpath, &file_stat) == -1) {
+			dE("Stat failed on %s: %u, %s", mibpath, errno, strerror(errno));
+			oval_ftsent_free(ofts_ent);
+			continue;
+		}
+		/* the sysctl utility uses same condition in sysctl.c in ReadSetting() */
+		if ((file_stat.st_mode & S_IRUSR) == 0) {
+			dI("Skipping write-only file %s", mibpath);
+			oval_ftsent_free(ofts_ent);
+			continue;
+		}
+
                 mib    = strdup(mibpath + strlen(PROC_SYS_DIR) + 1);
                 miblen = strlen(mib);
 
@@ -109,17 +138,19 @@ int probe_main(probe_ctx *ctx, void *probe_arg)
                         --miblen;
                 }
 
-                dI("MIB: %s\n", mib);
+                dI("MIB: %s", mib);
                 se_mib = SEXP_string_new(mib, strlen(mib));
                 oscap_free(mib);
 
                 if (probe_entobj_cmp(name_entity, se_mib) == OVAL_RESULT_TRUE) {
                         FILE   *fp;
                         SEXP_t *item;
-                        char    sysctl_value[512];
-                        size_t  i, l;
+                        char    sysval[8192];
+                        char   *sysvals[512];
+                        long i, l;
+                        size_t s;
 
-                        dI("MIB match\n");
+                        dI("MIB match");
 
                         /*
                          * read sysctl value
@@ -127,45 +158,73 @@ int probe_main(probe_ctx *ctx, void *probe_arg)
                         fp = fopen(mibpath, "r");
 
                         if (fp == NULL) {
-                                dE("Can't read sysctl value from \"%s\": %u, %s\n",
+                                dE("Can't read sysctl value from \"%s\": %u, %s",
                                    mibpath, errno, strerror(errno));
                                 goto fail_item;
                         }
 
-                        l = fread(sysctl_value, 1, sizeof sysctl_value - 1, fp);
+                        l = fread(sysval, 1, sizeof sysval - 1, fp);
 
                         if (ferror(fp)) {
-                                dE("An error ocured when reading from \"%s\" (fp=%p): %u, %s\n",
-                                   mibpath, fp, errno, strerror(errno));
-                                goto fail_item;
+				/* Linux 4.1.0 introduced a per-NIC IPv6 stable_secret file.
+				 * The stable_secret file cannot be read until it is set,
+				 * so we skip it when it is not readable. Otherwise we collect it.
+				 */
+				if (strncmp(ofts_ent->path, ipv6_conf_path, ipv6_conf_path_len) == 0 &&
+						strcmp(ofts_ent->file, "stable_secret") == 0) {
+					dI("Skippping file %s", mibpath);
+					oval_ftsent_free(ofts_ent);
+					SEXP_free(se_mib);
+					fclose(fp);
+					continue;
+				} else {
+					dE("An error ocured when reading from \"%s\" (fp=%p): l=%ld, %u, %s",
+						mibpath, fp, l, errno, strerror(errno));
+					goto fail_item;
+				}
                         }
 
                         fclose(fp);
-                        assume_d(l < sizeof sysctl_value, NULL);
 
                         /*
                          * sanitize the value
                          *  - only printable and whitespace chars allowed
                          *  - remove the last '\n'
                          */
-                        for(i = 0; i < l; ++i) {
-                                if (!isprint(sysctl_value[i]) && !isspace(sysctl_value[i])) {
-                                        sysctl_value[i] = '\0';
-                                        break;
+                        sysvals[0] = sysval;
+
+                        for(s = 0, i = 0; i < l && s < sizeof sysvals/sizeof(char *) - 1; ++i) {
+	                        if ((!isprint(sysval[i]) && !isspace(sysval[i]))
+	                            || (over_cmp >= 0 && sysval[i] == '\n' /* OVAL 5.10 and above */))
+                                {
+                                        sysval[i] = '\0';
+                                        sysvals[++s] = sysval + i + 1;
                                 }
                         }
 
-                        if (sysctl_value[l - 1] == '\n')
-                                sysctl_value[l - 1] = '\0';
+                        if (sysval[l - 1] == '\n')
+                                sysval[l - 1] = '\0';
                         else
-                                sysctl_value[l] = '\0';
+                                sysval[l] = '\0';
 
-                        dI("sanitized value: %s\n", sysctl_value);
+                        if (strlen(sysvals[s]) == 0)
+                                sysvals[s] = NULL;
+                        else
+                                sysvals[++s] = NULL;
+
+                        if (over_cmp >= 0) {
+	                        /* Only in OVAL 5.10 and above */
+	                        item = probe_item_create(OVAL_UNIX_SYSCTL, NULL,
+	                                                 "name",  OVAL_DATATYPE_SEXP,   se_mib,
+	                                                 "value", OVAL_DATATYPE_STRING_M, sysvals,
+	                                                 NULL);
+                        } else {
+	                        item = probe_item_create(OVAL_UNIX_SYSCTL, NULL,
+	                                                 "name",  OVAL_DATATYPE_SEXP,   se_mib,
+	                                                 "value", OVAL_DATATYPE_STRING, sysval,
+	                                                 NULL);
+                        }
 
-                        item = probe_item_create(OVAL_UNIX_SYSCTL, NULL,
-                                                 "name",  OVAL_DATATYPE_SEXP,   se_mib,
-                                                 "value", OVAL_DATATYPE_STRING, sysctl_value,
-                                                 NULL);
                         goto add_item;
                 fail_item:
                         if (fp != NULL)
