@@ -37,6 +37,7 @@
 #include <ctype.h>
 #include "oval_agent_api_impl.h"
 #include "results/oval_results_impl.h"
+#include "results/oval_status_counter.h"
 #include "oval_cmp_impl.h"
 #include "adt/oval_collection_impl.h"
 #include "adt/oval_string_map_impl.h"
@@ -235,7 +236,7 @@ oval_result_t ores_get_result_bychk(struct oresults *ores, oval_check_t check)
 		break;
 	case OVAL_CHECK_NONE_EXIST:
 		dW("The 'none exist' CheckEnumeration value has been deprecated. "
-		   "Converted to check='none satisfy'.\n");
+		   "Converted to check='none satisfy'.");
 		/* FALLTHROUGH */
 	case OVAL_CHECK_NONE_SATISFY:
 		if (ores->true_cnt > 0) {
@@ -410,13 +411,17 @@ static inline oval_result_t _evaluate_sysent_with_variable(struct oval_syschar_m
 			var_val = oval_value_iterator_next(val_itr);
 			state_entity_val_text = oval_value_get_text(var_val);
 			if (state_entity_val_text == NULL) {
-				dE("Found NULL variable value text.\n");
+				dE("Found NULL variable value text.");
 				ores_add_res(&var_ores, OVAL_RESULT_ERROR);
 				break;
 			}
 			oval_datatype_t state_entity_val_datatype = oval_value_get_datatype(var_val);
 
 			var_val_res = oval_ent_cmp_str(state_entity_val_text, state_entity_val_datatype, item_entity, state_entity_operation);
+			if (var_val_res == OVAL_RESULT_ERROR) {
+				dE("Error occured when comparing a variable '%s' value '%s' with collected item entity = '%s'",
+					oval_variable_get_id(state_entity_var), state_entity_val_text, oval_sysent_get_value(item_entity));
+			}
 			ores_add_res(&var_ores, var_val_res);
 		}
 		oval_value_iterator_free(val_itr);
@@ -481,9 +486,11 @@ static oval_result_t eval_item(struct oval_syschar_model *syschar_model, struct
 		char *state_entity_name;
 		oval_operation_t state_entity_operation;
 		oval_check_t entity_check;
+		oval_existence_t check_existence;
 		oval_result_t ste_ent_res;
 		struct oval_sysent_iterator *item_entities_itr;
 		struct oresults ent_ores;
+		struct oval_status_counter counter;
 		bool found_matching_item;
 
 		if ((content = oval_state_content_iterator_next(state_contents_itr)) == NULL) {
@@ -507,24 +514,27 @@ static oval_result_t eval_item(struct oval_syschar_model *syschar_model, struct
 			 * (textfilecontent_item). In OVAL 5.3 and below this syschar did not hold any usable
 			 * information ('text' ent). In OVAL 5.4 textfilecontent_test was deprecated. But the
 			 * 'text' ent has been added to textfilecontent_item, making it potentially usable. */
-			oval_version_t over = oval_state_get_schema_version(state);
-			if (oval_version_cmp(over, OVAL_VERSION(5.4)) >= 0) {
+			oval_schema_version_t over = oval_state_get_platform_schema_version(state);
+			if (oval_schema_version_cmp(over, OVAL_SCHEMA_VERSION(5.4)) >= 0) {
 				/* The OVAL-5.3 does not have textfilecontent_item/text */
 				state_entity_name = "text";
 			}
 		}
 
 		entity_check = oval_state_content_get_ent_check(content);
+		check_existence = oval_state_content_get_check_existence(content);
 		state_entity_operation = oval_entity_get_operation(state_entity);
 
 		ores_clear(&ent_ores);
 		found_matching_item = false;
+		oval_status_counter_clear(&counter);
 
 		item_entities_itr = oval_sysitem_get_sysents(cur_sysitem);
 		while (oval_sysent_iterator_has_more(item_entities_itr)) {
 			struct oval_sysent *item_entity;
 			oval_result_t ent_val_res;
 			char *item_entity_name;
+			oval_syschar_status_t item_status;
 
 			item_entity = oval_sysent_iterator_next(item_entities_itr);
 			if (item_entity == NULL) {
@@ -532,6 +542,8 @@ static oval_result_t eval_item(struct oval_syschar_model *syschar_model, struct
 				oval_sysent_iterator_free(item_entities_itr);
 				goto fail;
 			}
+			item_status = oval_sysent_get_status(item_entity);
+			oval_status_counter_add_status(&counter, item_status);
 
 			item_entity_name = oval_sysent_get_name(item_entity);
 			if (strcmp(item_entity_name, state_entity_name))
@@ -555,11 +567,13 @@ static oval_result_t eval_item(struct oval_syschar_model *syschar_model, struct
 		oval_sysent_iterator_free(item_entities_itr);
 
 		if (!found_matching_item)
-			dW("Entity name '%s' from state (id: '%s') not found in item (id: '%s').\n",
+			dW("Entity name '%s' from state (id: '%s') not found in item (id: '%s').",
 			   state_entity_name, oval_state_get_id(state), oval_sysitem_get_id(cur_sysitem));
 
 		ste_ent_res = ores_get_result_bychk(&ent_ores, entity_check);
 		ores_add_res(&ste_ores, ste_ent_res);
+		oval_result_t cres = oval_status_counter_get_result(&counter, check_existence);
+		ores_add_res(&ste_ores, cres);
 	}
 	oval_state_content_iterator_free(state_contents_itr);
 
@@ -833,9 +847,12 @@ _oval_result_test_evaluate_items(struct oval_test *test, struct oval_syschar *sy
 			}
 		}
 		break;
-	default:
-		oscap_seterr(OSCAP_EFAMILY_OVAL, "Unknown syschar flag: %d.", oval_syschar_get_flag(syschar_object));
+	default: {
+		const char *object_id = oval_syschar_get_object(syschar_object) ? oval_object_get_id(oval_syschar_get_object(syschar_object)) : "<UNKNOWN>";
+		oscap_seterr(OSCAP_EFAMILY_OVAL, "Unknown syschar flag: '%d' when evaluating object: '%s' from test: '%s' ",
+				oval_syschar_get_flag(syschar_object), object_id, oval_test_get_id(test));
 		return OVAL_RESULT_ERROR;
+		}
 	}
 
 	return result;
@@ -848,7 +865,7 @@ static oval_result_t _oval_result_test_result(struct oval_result_test *rtest, vo
 
 	/* is the test already evaluated? */
 	if (rtest->result != OVAL_RESULT_NOT_EVALUATED) {
-		dI("Found result from previous evaluation: %d, returning without further processing.\n", rtest->result);
+		dI("Found result from previous evaluation: %d, returning without further processing.", rtest->result);
 		return (rtest->result);
 	}
 
@@ -862,7 +879,7 @@ static oval_result_t _oval_result_test_result(struct oval_result_test *rtest, vo
 
 	struct oval_syschar * syschar = oval_syschar_model_get_syschar(syschar_model, object_id);
 	if (syschar == NULL) {
-		dW("No syschar for object: %s\n", object_id);
+		dW("No syschar for object: %s", object_id);
 		return OVAL_RESULT_UNKNOWN;
 	}
 
@@ -974,7 +991,7 @@ oval_result_t oval_result_test_eval(struct oval_result_test *rtest)
 			rtest->result = OVAL_RESULT_UNKNOWN;
 	}
 
-        dI("\t%s => %s\n", oval_result_test_get_id(rtest), oval_result_get_text(rtest->result));
+        dI("\t%s => %s", oval_result_test_get_id(rtest), oval_result_get_text(rtest->result));
 
 	return rtest->result;
 }
@@ -1085,7 +1102,7 @@ static int _oval_result_test_parse(xmlTextReaderPtr reader, struct oval_parser_c
 	} else if (strcmp((const char *)localName, "tested_variable") == 0) {
 		return_code = _oval_result_test_binding_parse(reader, context, args);
 	} else {
-		dW( "Unhandled tag: <%s>.\n", localName);
+		dW("Unhandled tag: <%s>.", localName);
 		oval_parser_skip_tag(reader, context);
 	}
 
@@ -1121,7 +1138,7 @@ int oval_result_test_parse_tag(xmlTextReaderPtr reader, struct oval_parser_conte
 	if (tst_check_existence == OVAL_EXISTENCE_UNKNOWN) {
 		oval_test_set_existence(ovaltst, check_existence);
 	} else if (tst_check_existence != check_existence) {
-		oscap_dlprintf(DBG_W, "@check_existence does not match, test_id: %s.\n", test_id);
+		dW("@check_existence does not match, test_id: %s.", test_id);
 	}
 
 	oval_check_t check = oval_check_parse(reader, "check", OVAL_CHECK_UNKNOWN);
@@ -1129,7 +1146,7 @@ int oval_result_test_parse_tag(xmlTextReaderPtr reader, struct oval_parser_conte
 	if (tst_check == OVAL_CHECK_UNKNOWN) {
 		oval_test_set_check(ovaltst, check);
 	} else if (tst_check != check) {
-		oscap_dlprintf(DBG_W, "@check does not match, test_id: %s.\n", test_id);
+		dW("@check does not match, test_id: %s.", test_id);
 	}
 
 	int version = oval_parser_int_attribute(reader, "version", 0);
@@ -1137,7 +1154,7 @@ int oval_result_test_parse_tag(xmlTextReaderPtr reader, struct oval_parser_conte
 	if (tst_version == 0) {
 		oval_test_set_version(ovaltst, version);
 	} else if (tst_version != version) {
-		oscap_dlprintf(DBG_W, "@version does not match, test_id: %s.\n", test_id);
+		dW("@version does not match, test_id: %s.", test_id);
 	}
 
 	struct oval_string_map *itemmap = oval_string_map_new();
