@@ -1,5 +1,5 @@
 /*
- * Copyright 2009 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -37,6 +37,8 @@
 #include "common/_error.h"
 #include "common/debug_priv.h"
 #include "common/xmlns_priv.h"
+#include "source/oscap_source_priv.h"
+#include "source/public/oscap_source.h"
 
 struct xccdf_version_info {
 	const char* version; ///< MAJOR.MINOR, for example "1.1" or "1.2"
@@ -108,30 +110,28 @@ bool xccdf_is_supported_namespace(xmlNs *ns)
 		_namespace_get_xccdf_version_info((const char *) ns->href) != NULL;
 }
 
+char *xccdf_detect_version_priv(xmlTextReader *reader)
+{
+	while (xmlTextReaderRead(reader) == 1 && xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT);
+	const struct xccdf_version_info *ver_info = xccdf_detect_version_parser(reader);
+	if (ver_info == NULL) {
+		return NULL;
+	}
+	return oscap_strdup(xccdf_version_info_get_version(ver_info));
+}
+
 char * xccdf_detect_version(const char* file)
 {
-	const struct xccdf_version_info *ver_info;
-	char *doc_version;
-
-	xmlTextReaderPtr reader = xmlReaderForFile(file, NULL, 0);
+	struct oscap_source *source = oscap_source_new_from_file(file);
+	xmlTextReader *reader = oscap_source_get_xmlTextReader(source);
 	if (!reader) {
-		oscap_seterr(OSCAP_EFAMILY_GLIBC, "Unable to open file: '%s'", file);
+		oscap_source_free(source);
 		return NULL;
 	}
 
-	xmlTextReaderSetErrorHandler(reader, &libxml_error_handler, NULL);
-
-	while (xmlTextReaderRead(reader) == 1 && xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT);
-	ver_info = xccdf_detect_version_parser(reader);
-
-	if(!ver_info) {
-		xmlFreeTextReader(reader);
-		return NULL;
-	}
-	doc_version = strdup(xccdf_version_info_get_version(ver_info));
-
+	char *doc_version = xccdf_detect_version_priv(reader);
 	xmlFreeTextReader(reader);
-
+	oscap_source_free(source);
 	return doc_version;
 }
 
@@ -174,7 +174,7 @@ static const struct xccdf_element_spec XCCDF_ELEMENT_MAP[] = {
 	{XCCDFE_VALUE, XCCDF_XMLNS_PREFIX, "Value"},
 	{XCCDFE_PROFILE, XCCDF_XMLNS_PREFIX, "Profile"},
 	{XCCDFE_TESTRESULT, XCCDF_XMLNS_PREFIX, "TestResult"},
-	{XCCDFE_RESULT_BENCHMARK, XCCDF_XMLNS_PREFIX, "benchmark"},
+	{XCCDFE_RESULT_BENCHMARK, XCCDF_XMLNS_PREFIX, "benchmark"}, ///< this is also XCCDFE_BENCHMARK_REF
 	{XCCDFE_CHECK, XCCDF_XMLNS_PREFIX, "check"},
 	{XCCDFE_CHECK_IMPORT, XCCDF_XMLNS_PREFIX, "check-import"},
 	{XCCDFE_CHECK_EXPORT, XCCDF_XMLNS_PREFIX, "check-export"},
@@ -239,10 +239,19 @@ static const struct xccdf_element_spec XCCDF_ELEMENT_MAP[] = {
 	{XCCDFE_VALUE_VAL, XCCDF_XMLNS_PREFIX, "value"},
 	{XCCDFE_VERSION, XCCDF_OR_TAILORING_EXTENSION_XMLNS, "version"},
 	{XCCDFE_WARNING, XCCDF_XMLNS_PREFIX, "warning"},
-	{XCCDFE_BENCHMARK_REF, XCCDF_XMLNS_PREFIX, "benchmark"},
 	{0, NULL, NULL}
 };
 
+const char *xccdf_element_to_str(xccdf_element_t element)
+{
+	for (const struct xccdf_element_spec *mapptr = XCCDF_ELEMENT_MAP; mapptr->id != 0; ++mapptr) {
+		if (element == mapptr->id) {
+			return mapptr->name;
+		}
+	}
+	return NULL;
+}
+
 xccdf_element_t xccdf_element_get(xmlTextReaderPtr reader)
 {
 	if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT)
@@ -451,3 +460,15 @@ void xccdf_print_max(const char *str, int max, const char *ellipsis)
 		printf("%s", ellipsis);
 }
 
+xmlNs *lookup_xccdf_ns(xmlDoc *doc, xmlNode *parent, const struct xccdf_version_info *version_info)
+{
+	assert(parent != NULL);
+
+	xmlNs *ns_xccdf = xmlSearchNsByHref(doc, parent,
+		(const xmlChar *)xccdf_version_info_get_namespace_uri(version_info));
+	if (ns_xccdf == NULL) {
+		ns_xccdf = xmlNewNs(parent,
+			(const xmlChar *) xccdf_version_info_get_namespace_uri(version_info), NULL);
+	}
+	return ns_xccdf;
+}
