@@ -28,6 +28,7 @@
 
 #include "common/util.h"
 #include "common/elements.h"
+#include "common/_error.h"
 
 #include <libxml/xmlreader.h>
 
@@ -135,9 +136,10 @@ typedef enum {
 	XCCDFE_END_
 } xccdf_element_t;
 
+const char *xccdf_element_to_str(xccdf_element_t element);
 xccdf_element_t xccdf_element_get(xmlTextReaderPtr reader);
 
-#define XCCDF_ASSERT_ELEMENT(reader, element) do { if (xccdf_element_get(reader) != element) return false; } while(false)
+#define XCCDF_ASSERT_ELEMENT(reader, element) do { if (xccdf_element_get(reader) != element) { oscap_seterr(OSCAP_EFAMILY_XCCDF, "Find element '%s' while expecting element: '%s'", xccdf_element_to_str((xccdf_element_get(reader))), xccdf_element_to_str(element)); return false; } } while(false)
 
 typedef enum {
 	XCCDFA_NONE,
