@@ -44,6 +44,7 @@
 #include "common/_error.h"
 #include "oscap_text.h"
 #include "common/debug_priv.h"
+#include "source/oscap_source_priv.h"
 
 // constants
 static const xccdf_numeric XCCDF_SCORE_MAX_DAFAULT = 100.0f;
@@ -65,7 +66,7 @@ struct xccdf_result *xccdf_result_new(void)
 	struct xccdf_item *result = xccdf_item_new(XCCDF_RESULT, NULL);
 	oscap_create_lists(&result->sub.result.identities, &result->sub.result.targets,
 		&result->sub.result.remarks, &result->sub.result.target_addresses,
-		&result->sub.result.target_facts, &result->sub.result.target_id_refs,
+		&result->sub.result.target_facts, &result->sub.result.target_id_refs, &result->sub.result.applicable_platforms,
 		&result->sub.result.setvalues, &result->sub.result.organizations,
 		&result->sub.result.rule_results, &result->sub.result.scores, NULL);
 	return XRESULT(result);
@@ -93,8 +94,9 @@ static inline void xccdf_result_free_impl(struct xccdf_item *result)
 		oscap_list_free(result->sub.result.identities, (oscap_destruct_func) xccdf_identity_free);
 		oscap_list_free(result->sub.result.target_facts, (oscap_destruct_func) xccdf_target_fact_free);
 		oscap_list_free(result->sub.result.target_id_refs, (oscap_destruct_func) xccdf_target_identifier_free);
-		oscap_list_free(result->sub.result.scores, (oscap_destruct_func) xccdf_score_free);
+		oscap_list_free(result->sub.result.applicable_platforms, oscap_free);
 		oscap_list_free(result->sub.result.targets, oscap_free);
+		oscap_list_free(result->sub.result.scores, (oscap_destruct_func) xccdf_score_free);
 		oscap_list_free(result->sub.result.remarks, (oscap_destruct_func) oscap_text_free);
 		oscap_list_free(result->sub.result.target_addresses, oscap_free);
 		oscap_list_free(result->sub.result.setvalues, (oscap_destruct_func) xccdf_setvalue_free);
@@ -107,6 +109,7 @@ static inline void xccdf_result_free_impl(struct xccdf_item *result)
 
 XCCDF_FREE_GEN(result)
 
+XCCDF_ACCESSOR_SIMPLE(result, const struct xccdf_version_info*, schema_version);
 XCCDF_ACCESSOR_STRING(result, start_time)
 XCCDF_ACCESSOR_STRING(result, end_time)
 XCCDF_ACCESSOR_STRING(result, test_system)
@@ -119,6 +122,7 @@ XCCDF_LISTMANIP_STRING(result, organization, organizations)
 XCCDF_LISTMANIP_TEXT(result, remark, remarks)
 XCCDF_LISTMANIP(result, target_fact, target_facts)
 XCCDF_LISTMANIP(result, target_identifier, target_id_refs)
+XCCDF_LISTMANIP_STRING(result, applicable_platform, applicable_platforms)
 XCCDF_LISTMANIP(result, setvalue, setvalues)
 XCCDF_LISTMANIP(result, rule_result, rule_results)
 XCCDF_LISTMANIP(result, score, scores)
@@ -594,12 +598,30 @@ static struct xccdf_override *xccdf_override_new_parse(xmlTextReaderPtr reader);
 static struct xccdf_message *xccdf_message_new_parse(xmlTextReaderPtr reader);
 static struct xccdf_instance *xccdf_instance_new_parse(xmlTextReaderPtr reader);
 
+struct xccdf_result *xccdf_result_import_source(struct oscap_source *source)
+{
+	xmlTextReader *reader = oscap_source_get_xmlTextReader(source);
+	if (reader == NULL) {
+		return NULL;
+	}
+	while (xmlTextReaderRead(reader) == 1
+			&& xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT);
+	struct xccdf_result *result = xccdf_result_new_parse(reader);
+	xmlFreeTextReader(reader);
+	return result;
+}
+
 struct xccdf_result *xccdf_result_new_parse(xmlTextReaderPtr reader)
 {
 	assert(reader != NULL);
-	XCCDF_ASSERT_ELEMENT(reader, XCCDFE_TESTRESULT);
+	if (xccdf_element_get(reader) != XCCDFE_TESTRESULT) {
+		oscap_seterr(OSCAP_EFAMILY_XCCDF, "Expected 'TestResult' element while found '%s'.",
+				xmlTextReaderConstLocalName(reader));
+		return NULL;
+	}
 
 	struct xccdf_item *res = XITEM(xccdf_result_new());
+	xccdf_result_set_schema_version(XRESULT(res), xccdf_detect_version_parser(reader));
 
 	if (!xccdf_item_process_attributes(res, reader))
 		goto fail;
@@ -627,7 +649,7 @@ struct xccdf_result *xccdf_result_new_parse(xmlTextReaderPtr reader)
 			break;
 		case XCCDFE_RESULT_PROFILE:
 			if (res->sub.result.profile == NULL)
-				res->sub.result.profile = oscap_element_string_copy(reader);
+				res->sub.result.profile = xccdf_attribute_copy(reader, XCCDFA_IDREF);
 			break;
 		case XCCDFE_TARGET:
 			oscap_list_add(res->sub.result.targets, oscap_element_string_copy(reader));
@@ -680,21 +702,31 @@ fail:
 	return NULL;
 }
 
+struct oscap_source *xccdf_result_export_source(struct xccdf_result *result, const char *filepath)
+{
+	xmlDocPtr doc = xmlNewDoc(BAD_CAST "1.0");
+	if (doc == NULL) {
+		oscap_setxmlerr(xmlGetLastError());
+		return NULL;
+	}
+
+	xccdf_result_to_dom(result, NULL, doc, NULL);
+	return oscap_source_new_from_xmlDoc(doc, filepath);
+}
+
 int xccdf_result_export(struct xccdf_result *result, const char *file)
 {
 	__attribute__nonnull__(file);
 
 	LIBXML_TEST_VERSION;
 
-	xmlDocPtr doc = xmlNewDoc(BAD_CAST "1.0");
-	if (doc == NULL) {
-		oscap_setxmlerr(xmlGetLastError());
+	struct oscap_source *result_source = xccdf_result_export_source(result, file);
+	if (result_source == NULL) {
 		return -1;
 	}
-
-	xccdf_result_to_dom(result, NULL, doc, NULL);
-
-	return oscap_xml_save_filename(file, doc);
+	int ret = oscap_source_save_as(result_source, NULL);
+	oscap_source_free(result_source);
+	return ret;
 }
 
 void xccdf_result_to_dom(struct xccdf_result *result, xmlNode *result_node, xmlDoc *doc, xmlNode *parent)
@@ -703,10 +735,9 @@ void xccdf_result_to_dom(struct xccdf_result *result, xmlNode *result_node, xmlD
 	const char *benchmark_ref_uri = xccdf_result_get_benchmark_uri(result);
 	const struct xccdf_version_info* version_info = xccdf_item_get_schema_version(XITEM(result));
 	if (parent) {
-	        ns_xccdf = xmlSearchNsByHref(doc, parent,
-	        		(const xmlChar*)xccdf_version_info_get_namespace_uri(version_info));
+	        ns_xccdf = lookup_xccdf_ns(doc, parent, version_info);
 	} else {
-		if (!result_node) result_node = xccdf_item_to_dom(XITEM(result), doc, NULL);
+		if (!result_node) result_node = xccdf_item_to_dom(XITEM(result), doc, NULL, version_info);
                 ns_xccdf = xmlNewNs(result_node,
                 		(const xmlChar*)xccdf_version_info_get_namespace_uri(version_info), NULL);
 		xmlDocSetRootElement(doc, result_node);
@@ -765,6 +796,9 @@ void xccdf_result_to_dom(struct xccdf_result *result, xmlNode *result_node, xmlD
 		xmlNewProp(result_node, BAD_CAST "start-time", BAD_CAST start);
 	}
 	xmlNewProp(result_node, BAD_CAST "end-time", BAD_CAST xccdf_result_get_end_time(result));
+	const char *version = xccdf_result_get_version(result);
+        if (version != NULL)
+		xmlNewProp(result_node, BAD_CAST "version", BAD_CAST version);
 
 	/* Handle children */
 	xccdf_texts_to_dom(xccdf_result_get_remarks(result), result_node, "remark");
@@ -799,13 +833,6 @@ void xccdf_result_to_dom(struct xccdf_result *result, xmlNode *result_node, xmlD
 		xmlNewProp(prof_node, BAD_CAST "idref", BAD_CAST profile);
 	}
 
-	struct xccdf_setvalue_iterator *setvalues = xccdf_result_get_setvalues(result);
-	while (xccdf_setvalue_iterator_has_more(setvalues)) {
-		struct xccdf_setvalue *setvalue = xccdf_setvalue_iterator_next(setvalues);
-		xccdf_setvalue_to_dom(setvalue, doc, result_node, version_info);
-	}
-	xccdf_setvalue_iterator_free(setvalues);
-
 	struct oscap_string_iterator *targets = xccdf_result_get_targets(result);
 	while (oscap_string_iterator_has_more(targets)) {
 		const char *target = oscap_string_iterator_next(targets);
@@ -858,6 +885,21 @@ void xccdf_result_to_dom(struct xccdf_result *result, xmlNode *result_node, xmlD
 	}
 	xccdf_target_identifier_iterator_free(target_id_refs);
 
+	struct oscap_string_iterator *applicable_platforms = xccdf_result_get_applicable_platforms(result);
+	while (oscap_string_iterator_has_more(applicable_platforms)) {
+		const char *platform = oscap_string_iterator_next(applicable_platforms);
+		xmlNode *platform_element = xmlNewTextChild(result_node, ns_xccdf, BAD_CAST "platform", NULL);
+		xmlNewProp(platform_element, BAD_CAST "idref", BAD_CAST platform);
+	}
+	oscap_string_iterator_free(applicable_platforms);
+
+	struct xccdf_setvalue_iterator *setvalues = xccdf_result_get_setvalues(result);
+	while (xccdf_setvalue_iterator_has_more(setvalues)) {
+		struct xccdf_setvalue *setvalue = xccdf_setvalue_iterator_next(setvalues);
+		xccdf_setvalue_to_dom(setvalue, doc, result_node, version_info);
+	}
+	xccdf_setvalue_iterator_free(setvalues);
+
 	struct xccdf_rule_result_iterator *rule_results = xccdf_result_get_rule_results(result);
 	while (xccdf_rule_result_iterator_has_more(rule_results)) {
 		struct xccdf_rule_result *rule_result = xccdf_rule_result_iterator_next(rule_results);
@@ -994,8 +1036,7 @@ xmlNode *xccdf_target_identifier_to_dom(const struct xccdf_target_identifier *ti
 		return ret;
 	}
 	else {
-		xmlNs *ns_xccdf = xmlSearchNsByHref(doc, parent,
-				(const xmlChar*)xccdf_version_info_get_namespace_uri(version_info));
+		xmlNs *ns_xccdf = lookup_xccdf_ns(doc, parent, version_info);
 
 		xmlNode *target_idref_node = xmlNewTextChild(parent, ns_xccdf, BAD_CAST "target-id-ref", NULL);
 
@@ -1018,8 +1059,7 @@ xmlNode *xccdf_target_identifier_to_dom(const struct xccdf_target_identifier *ti
 
 xmlNode *xccdf_rule_result_to_dom(struct xccdf_rule_result *result, xmlDoc *doc, xmlNode *parent, const struct xccdf_version_info* version_info)
 {
-	xmlNs *ns_xccdf = xmlSearchNsByHref(doc, parent,
-			(const xmlChar*)xccdf_version_info_get_namespace_uri(version_info));
+	xmlNs *ns_xccdf = lookup_xccdf_ns(doc, parent, version_info);
 
 	xmlNode *result_node = xmlNewTextChild(parent, ns_xccdf, BAD_CAST "rule-result", NULL);
 
@@ -1100,7 +1140,7 @@ xmlNode *xccdf_rule_result_to_dom(struct xccdf_rule_result *result, xmlDoc *doc,
 	struct xccdf_fix_iterator *fixes = xccdf_rule_result_get_fixes(result);
 	while (xccdf_fix_iterator_has_more(fixes)) {
 		struct xccdf_fix *fix = xccdf_fix_iterator_next(fixes);
-		xccdf_fix_to_dom(fix, doc, result_node);
+		xccdf_fix_to_dom(fix, doc, result_node, version_info);
 	}
 	xccdf_fix_iterator_free(fixes);
 
@@ -1114,6 +1154,21 @@ xmlNode *xccdf_rule_result_to_dom(struct xccdf_rule_result *result, xmlDoc *doc,
 	return result_node;
 }
 
+bool xccdf_rule_result_override(struct xccdf_rule_result *rule_result, xccdf_test_result_type_t new_result, const char *waiver_time, const char *authority, struct oscap_text *remark)
+{
+	struct xccdf_override *o= xccdf_override_new();
+	xccdf_override_set_old_result(o, xccdf_rule_result_get_result(rule_result));
+	xccdf_override_set_new_result(o, new_result);
+	xccdf_override_set_time(o, waiver_time);
+	xccdf_override_set_authority(o, authority);
+	xccdf_override_set_remark(o, remark);
+	if (!xccdf_rule_result_add_override(rule_result, o)) {
+		xccdf_override_free(o);
+		return false;
+	}
+	return xccdf_rule_result_set_result(rule_result, new_result);
+}
+
 static struct xccdf_override *xccdf_override_new_parse(xmlTextReaderPtr reader)
 {
 	XCCDF_ASSERT_ELEMENT(reader, XCCDFE_OVERRIDE);
@@ -1147,8 +1202,7 @@ static struct xccdf_override *xccdf_override_new_parse(xmlTextReaderPtr reader)
 
 xmlNode *xccdf_override_to_dom(struct xccdf_override *override, xmlDoc *doc, xmlNode *parent, const struct xccdf_version_info* version_info)
 {
-	xmlNs *ns_xccdf = xmlSearchNsByHref(doc, parent,
-			(const xmlChar*)xccdf_version_info_get_namespace_uri(version_info));
+	xmlNs *ns_xccdf = lookup_xccdf_ns(doc, parent, version_info);
 
 	xmlNode *override_node = xmlNewTextChild(parent, ns_xccdf, BAD_CAST "override", NULL);
 
