@@ -59,7 +59,7 @@ static int _xccdf_text_substitution_cb(xmlNode **node, void *user_data)
 
 	if (oscap_streq((const char *) (*node)->name, "sub") && xccdf_is_supported_namespace((*node)->ns)) {
 		if ((*node)->children != NULL)
-			dW("The xccdf:sub element SHALL NOT have any content.\n");
+			dW("The xccdf:sub element SHALL NOT have any content.");
 		char *sub_idref = (char *) xmlGetProp(*node, BAD_CAST "idref");
 		if (oscap_streq(sub_idref, NULL)) {
 			oscap_seterr(OSCAP_EFAMILY_XCCDF, "The xccdf:sub MUST have a single @idref attribute.");
@@ -94,7 +94,7 @@ static int _xccdf_text_substitution_cb(xmlNode **node, void *user_data)
 				oscap_text_iterator_free(title_it);
 			} else {
 				if (!oscap_streq(sub_use, "value"))
-					dW("xccdf:sub/@idref='%s' has incorrect @use='%s'! Using @use='value' instead.\n", sub_idref, sub_use);
+					dW("xccdf:sub/@idref='%s' has incorrect @use='%s'! Using @use='value' instead.", sub_idref, sub_use);
 				result = xccdf_policy_get_value_of_item(data->policy, value);
 			}
 			oscap_free(sub_use);
@@ -135,7 +135,7 @@ static int _xccdf_text_substitution_cb(xmlNode **node, void *user_data)
 			} else {
 				result = xccdf_benchmark_get_plain_text(benchmark, value_id);
 				if (result == NULL) {
-					dW("Text substitution for xccdf:fact is not supported!\n"); // TODO.
+					dW("Text substitution for xccdf:fact is not supported!"); // TODO.
 				}
 			}
 		}
@@ -154,7 +154,7 @@ static int _xccdf_text_substitution_cb(xmlNode **node, void *user_data)
 		else {
 			// Let's not consider this as an error. Since in similar cases NISTIR-7275r4
 			// suggests to retain the <object> element.
-			dW("Unsupported XCCDF uri: xhtml:object/@data='%s'\n", object_data);
+			dW("Unsupported XCCDF uri: xhtml:object/@data='%s'", object_data);
 			free(object_data);
 			return 0;
 		}
@@ -168,16 +168,18 @@ static int _xccdf_text_substitution_cb(xmlNode **node, void *user_data)
 		const char *result;
 		// <instance> elements
 		if ((*node)->children != NULL)
-			dW("The xccdf:instance element SHALL NOT have any content.\n");
+			dW("The xccdf:instance element SHALL NOT have any content.");
 		if (data->rule_result == NULL)
 			return 1;
 		struct xccdf_instance_iterator *instances = xccdf_rule_result_get_instances(data->rule_result);
 		if (xccdf_instance_iterator_has_more(instances)) {
 			struct xccdf_instance *instance = xccdf_instance_iterator_next(instances);
 			result = xccdf_instance_get_content(instance);
+			xccdf_instance_iterator_free(instances);
 		}
 		else {
-			dW("The xccdf:rule-result/xccdf:instance element was not found.\n");
+			xccdf_instance_iterator_free(instances);
+			dW("The xccdf:rule-result/xccdf:instance element was not found.");
 			return 1;
 		}
 		xmlNode *new_node = xmlNewText(BAD_CAST result);
