@@ -356,6 +356,8 @@ char **oscap_split(char *str, const char *delim);
 int oscap_strcmp(const char *s1, const char *s2);
 /// Check for string equality
 bool oscap_streq(const char *s1, const char *s2);
+bool oscap_str_startswith(const char *str, const char *with);
+bool oscap_str_endswith(const char *str, const char *with);
 /// Trim whitespace (modifies its argument!)
 char *oscap_trim(char *str);
 /// Print to a newly allocated string using a va_list.
@@ -379,12 +381,6 @@ void oscap_strtoupper(char *str);
 // check pointer equality
 bool oscap_ptr_cmp(void *node1, void *node2);
 
-/**
- * validate given XML file
- * @return 0 on pass; -1 error; 1 fail
- */
-int oscap_validate_xml(const char *xmlfile, const char *schemafile, xml_reporter reporter, void *arg);
-
 /**
  * find file with given name and mode in given paths
  * @param filename filename to be found
