@@ -8,7 +8,7 @@
 # Authors:
 #      Ondrej Moris <omoris@redhat.com>
 
-. $srcdir/../../../test_common.sh
+. ../../../test_common.sh
 
 # Test cases. 
 
