@@ -11,7 +11,7 @@
 
 
 
-. $srcdir/../../test_common.sh
+. ../../test_common.sh
 
 # Test cases.
 
