@@ -11,32 +11,28 @@
 #      Peter Vrabec, <pvrabec@redhat.com>
 #      Ondrej Moris, <omoris@redhat.com>
 
-. ${srcdir}/../../test_common.sh
+. ../../test_common.sh
 
 
 # Test Cases.
 
 function test_api_oval_definition {
     ./test_api_oval ${srcdir}/scap-rhel5-oval.xml
-    return $?
 }
 
 function test_api_oval_syschar {
     ./test_api_syschar $srcdir/composed-oval.xml \
 	$srcdir/system-characteristics.xml
-    return $?
 }
 
 function test_api_oval_results {
     ./test_api_results $srcdir/results.xml exported-results.xml
     cmp $srcdir/results-good.xml exported-results.xml
-    return $?
 }
 
 function test_api_oval_directives {
     ./test_api_directives $srcdir/directives.xml exported-directives.xml
     cmp $srcdir/directives.xml exported-directives.xml
-    return $?
 }
 
 # Testing.
