@@ -11,7 +11,7 @@
 #      David Niemoller
 #      Ondrej Moris <omoris@redhat.com>
 
-. $srcdir/../../test_common.sh
+. ../../test_common.sh
 
 # Test cases.
 
@@ -126,13 +126,7 @@ function test_api_seap_incorrect_expression {
 	ret_val=$[$ret_val+$?]
     done 
 
-    if [ $ret_val -eq ${#ARGS[@]} ]; then
-	ret_val=0
-    else
-	ret_val=1
-    fi
-
-    return $ret_val
+    return $([ $ret_val -eq ${#ARGS[@]} ])
 }
 
 # Parsing correct expression.
@@ -482,6 +476,10 @@ function test_api_seap_concurency {
     return $ret_val
 }
 
+function test_api_strto {
+    ./test_api_strto
+}
+
 # Testing.
 
 test_init "test_api_seap.log"
@@ -495,5 +493,6 @@ test_run "test_api_seap_list"                 ./test_api_seap_list
 test_run "test_api_seap_number_expression"    ./test_api_seap_number
 test_run "test_api_seap_string_expression"    ./test_api_seap_string
 test_run "test_api_SEXP_deepcmp"              ./test_api_SEXP_deepcmp
+test_run "test_api_strto"                     ./test_api_strto
 
 test_exit
