@@ -18,13 +18,13 @@ function test_api_xccdf_export {
 	local INPUT=$srcdir/$1
 	local OUTPUT=$1.out
 
-	./test_api_xccdf --export $srcdir/$INPUT $OUTPUT
+	./test_api_xccdf --export $INPUT $OUTPUT
 
 	# Workaround libxml2 on rhel5 which exports namespace declarations in different order.
 	sed -i 's|<cpe-list xmlns="http://cpe.mitre.org/XMLSchema/cpe/1.0" xmlns:meta="http://scap.nist.gov/schema/cpe-dictionary-metadata/0.2" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"|<cpe-list xmlns:meta="http://scap.nist.gov/schema/cpe-dictionary-metadata/0.2" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="http://cpe.mitre.org/XMLSchema/cpe/1.0"|' $OUTPUT
 
 	if [ $? -eq 0 ]; then
-		if ! $XMLDIFF $srcdir/$INPUT $OUTPUT; then
+		if ! $XMLDIFF $INPUT $OUTPUT; then
 			echo "Exported file differs from what is expected!"
 			return 1
 		fi
