@@ -40,7 +40,7 @@ assert_exists 1 '//rule-result/result[text()="error"]'
 assert_exists 1 '//rule-result/fix'
 assert_exists 3 '//rule-result/message'
 assert_exists 3 '//rule-result/message[@severity="info"]'
-assert_exists 1 '//rule-result/message[text()="Fix execution comleted and returned: 0"]'
+assert_exists 1 '//rule-result/message[text()="Fix execution completed and returned: 0"]'
 assert_exists 1 '//rule-result/message[text()="Failed to verify applied fix: Checking engine returns: fail"]'
 assert_exists 1 '//score'
 assert_exists 1 '//score[text()="0.000000"]'
