@@ -1,5 +1,5 @@
 /*
- * Copyright 2010--2014 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2010--2016 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -35,6 +35,7 @@
 
 #include "oscap-tool.h"
 #include "check_engine_plugin.h"
+#include "oscap_source.h"
 
 static bool getopt_root(int argc, char **argv, struct oscap_action *action);
 static int print_versions(const struct oscap_action*);
@@ -107,7 +108,7 @@ bool getopt_root(int argc, char **argv, struct oscap_action *action)
 
 static int print_versions(const struct oscap_action *action)
 {
-	printf("OpenSCAP command line tool (oscap) %s\n" "Copyright 2009--2014 Red Hat Inc., Durham, North Carolina.\n\n",
+	printf("OpenSCAP command line tool (oscap) %s\n" "Copyright 2009--2016 Red Hat Inc., Durham, North Carolina.\n\n",
 		oscap_get_version());
 
 	printf("==== Supported specifications ====\n");
@@ -145,7 +146,6 @@ static int print_versions(const struct oscap_action *action)
 
 	printf("==== Paths ====\n");
 	printf("Schema files: %s\n", oscap_path_to_schemas());
-	printf("Schematron files: %s\n", oscap_path_to_schematron());
 	printf("Default CPE files: %s\n", oscap_path_to_cpe());
 	printf("Probes: %s\n", oval_probe_ext_getdir());
 	printf("\n");
@@ -153,7 +153,9 @@ static int print_versions(const struct oscap_action *action)
 	printf("==== Inbuilt CPE names ====\n");
 	char default_cpe_path[PATH_MAX];
 	snprintf(default_cpe_path, PATH_MAX, "%s/openscap-cpe-dict.xml", oscap_path_to_cpe());
-	struct cpe_dict_model* cpe_dict = cpe_dict_model_import(default_cpe_path);
+	struct oscap_source *source = oscap_source_new_from_file(default_cpe_path);
+	struct cpe_dict_model* cpe_dict = cpe_dict_model_import_source(source);
+	oscap_source_free(source);
 	if (cpe_dict != NULL) {
 
 		struct cpe_item_iterator* cpe_items = cpe_dict_model_get_items(cpe_dict);
@@ -184,15 +186,6 @@ static int print_versions(const struct oscap_action *action)
 	return OSCAP_OK;
 }
 
-void validation_failed(const char *xmlfile, oscap_document_type_t doc_type, const char *version) {
-
-	const char *doc_name = oscap_document_type_to_string(doc_type);
-	if (doc_name == NULL)
-		fprintf(stderr, "Unrecognized document type.\n");
-	else
-		fprintf(stderr, "Invalid %s content(%s) in %s.\n", doc_name, version, xmlfile);
-}
-
 int reporter(const char *file, int line, const char *msg, void *arg) {
 	fprintf(stderr, "File '%s' line %d: %s", file, line, msg);
 	return 0;
